//     XILINX IS PROVIDING THIS DESIGN, CODE, OR INFORMATION "AS IS"
//     SOLELY FOR USE IN DEVELOPING PROGRAMS AND SOLUTIONS FOR
//     XILINX DEVICES.  BY PROVIDING THIS DESIGN, CODE, OR INFORMATION
//     AS ONE POSSIBLE IMPLEMENTATION OF THIS FEATURE, APPLICATION
//     OR STANDARD, XILINX IS MAKING NO REPRESENTATION THAT THIS
//     IMPLEMENTATION IS FREE FROM ANY CLAIMS OF INFRINGEMENT,
//     AND YOU ARE RESPONSIBLE FOR OBTAINING ANY RIGHTS YOU MAY REQUIRE
//     FOR YOUR IMPLEMENTATION.  XILINX EXPRESSLY DISCLAIMS ANY
//     WARRANTY WHATSOEVER WITH RESPECT TO THE ADEQUACY OF THE
//     IMPLEMENTATION, INCLUDING BUT NOT LIMITED TO ANY WARRANTIES OR
//     REPRESENTATIONS THAT THIS IMPLEMENTATION IS FREE FROM CLAIMS OF
//     INFRINGEMENT, IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
//     FOR A PARTICULAR PURPOSE.
//
//     (c) Copyright 2002 Xilinx, Inc.
//     All rights reserved.
//


/*
-------------------------------------------------------------------------------
   Title      : SVGA Video COLOR LOOK UP TABLE
   Project    : MicroBlaze Demo Board
-------------------------------------------------------------------------------
   File       : CLUT.v
   Company    : Xilinx, Inc.
   Created    : 2001/07/17
   Last Update: 2001/07/17
   Copyright  : (c) Xilinx Inc, 2001
-------------------------------------------------------------------------------
   Uses       : 
-------------------------------------------------------------------------------
   Used by    : COLOR_CHAR_MODE_SVGA_CTRL.v
-------------------------------------------------------------------------------
   Description: This module creates a 24 bit RGB color from a 4 bits from the color RAM.
			The colors are taken from the DOS (Windows) 16 color palette and use
			the DOS index.

	The colors are:		DOS Index:
	Black				0
	Navy				1
	Green				2
	Teal				3
	Maroon			4
	Purple			5
	Olive				6
	Silver			7
	Grey				8
	Blue				9
	Lime Green			10
	Cyan				11
	Red				12
	Magenta			13
	Yellow			14
	White				15

-------------------------------------------------------------------------------
-------------------------------------------------------------------------------
*/


module CLUT (aligned_color_data, pixel_data, pixel_clock, reset, red_data, green_data, blue_data);
input	 [3:0] aligned_color_data;	// the color of the character
input		 pixel_data;		// serialized pixel data from the character generator ROM
input		 pixel_clock;	// pixel clock
input		 reset;		// reset
output[7:0]  red_data;		// RED output data
output[7:0]  green_data;	// GREEN output data
output[7:0]  blue_data;		// BLUE output data

reg	[7:0]  red_data;		// RED output data
reg	[7:0]  green_data;	// GREEN output data
reg	[7:0]  blue_data;		// BLUE output data
reg	[7:0]  red;		
reg	[7:0]  green;	
reg	[7:0]  blue;

// create the color look up table
always @ (aligned_color_data or pixel_data) begin
casex ({pixel_data,aligned_color_data})

	5'b0XXXX:begin		// pixel is not on
		red 	= 8'h00;
		green = 8'h00;
		blue 	= 8'h00;
		end

	5'b10000:begin		// pixel is BLACK
		red 	= 8'h00;
		green = 8'h00;
		blue 	= 8'h00;
		end

	5'b10001:begin		// pixel is NAVY
		red 	= 8'h00;
		green = 8'h00;
		blue 	= 8'h80;
		end

	5'b10010:begin		// pixel is GREEN
		red 	= 8'h00;
		green = 8'h80;
		blue 	= 8'h00;
		end

	5'b10011:begin		// pixel is TEAL
		red 	= 8'h00;
		green = 8'h80;
		blue 	= 8'h80;
		end


	5'b10100:begin		// pixel is MAROON
		red 	= 8'h80;
		green = 8'h00;
		blue 	= 8'h00;
		end

	5'b10101:begin		// pixel is PURPLE
		red 	= 8'h80;
		green = 8'h00;
		blue 	= 8'h80;
		end

	5'b10110:begin		// pixel is OLIVE
		red 	= 8'h80;
		green = 8'h80;
		blue 	= 8'h00;
		end


	5'b10111:begin		// pixel is SILVER
		red 	= 8'hC0;
		green = 8'hC0;
		blue 	= 8'hC0;
		end

	5'b11000:begin		// pixel is GREY
		red 	= 8'h80;
		green = 8'h80;
		blue 	= 8'h80;
		end

	5'b11001:begin		// pixel is BLUE
		red 	= 8'h00;
		green = 8'h00;
		blue 	= 8'hFF;
		end

	5'b11010:begin		// pixel is LIME GREEN
		red 	= 8'h00;
		green = 8'hFF;
		blue 	= 8'h00;
		end

	5'b11011:begin		// pixel is CYAN
		red 	= 8'h00;
		green = 8'hFF;
		blue 	= 8'hFF;
		end

	5'b11100:begin		// pixel is RED
		red 	= 8'hFF;
		green = 8'h00;
		blue 	= 8'h00;
		end

	5'b11101:begin		// pixel is CYAN
		red 	= 8'hFF;
		green = 8'h00;
		blue 	= 8'hFF;
		end


	5'b11110:begin		// pixel is YELLOW
		red 	= 8'hFF;
		green = 8'hFF;
		blue 	= 8'h00;
		end

	5'b11111:begin		// pixel is WHITE
		red 	= 8'hFF;
		green = 8'hFF;
		blue 	= 8'hFF;
		end
	default:begin		
		red 	= 8'h00;
		green = 8'h00;
		blue 	= 8'h00;
		end
endcase
end

always @ (posedge pixel_clock or posedge reset) begin
	if (reset) begin
		red_data 	<= 8'h00;
		green_data 	<= 8'h00;
		blue_data 	<= 8'h00;
		end
	else begin
		red_data 	<= red;
		green_data 	<= green;
		blue_data 	<= blue;
		end
	end

endmodule //CLUT

