/******************************************************************************
*
* 	2 player Network Poker using Xilinx Multimedia Boards
* 	Authors:	Lyndon Carvalho and Hin Chan
*			ECE532 - Digital Hardware 2004/2005
*			Prof. Paul Chow
*			University of Toronto
* 
* 	Description: 	Server for a 2 player network poker game between 2
*			Xilinx Multimedia Boards connected thru a hub via
*			the ethernet
*
*******************************************************************************/
               

#include "SingleMB_DebuggingFunctions.h"


/*
*   returns the character equivalent of an integer
*/
char map(int x)      
{
	switch(x)
	{
	case 0:
		return '0';
	case 1:
		return '1';
	case 2:
		return '2';
	case 3:
		return '3';
	case 4:
		return '4';
	case 5:
		return '5';
	case 6:
		return '6';
	case 7:
		return '7';
	case 8:
		return '8';
	case 9:
		return '9';
	case 10:
		return 'A';
	case 11:
		return 'B';
	case 12:
		return 'C';
	case 13:
		return 'D';
	case 14:
		return 'E';
	case 15:
		return 'F';	
	}
}
 

/*
* Pass it a Pointer to the start of the Ethernet Header
* Returns the Layer 2 Type Field
*/
Xuint16 GetType(Xuint8 *MsgBuffer)
{
	Xuint8 * Ptr = MsgBuffer;
	Ptr+=14;
	return *(Xuint16 *)Ptr;
}

/*
* Pass it a Pointer to the start of the Ethernet Header
* Returns the Layer 2 Sequence Number Field
*/
Xuint32 GetSeqNum(Xuint8 *MsgBuffer)
{
	Xuint8 * Ptr = MsgBuffer;
	Ptr+=16;
	return *(Xuint32 *)Ptr;
}

/*
* Pass it a Pointer to the start of the Ethernet Header
* Returns the Layer 2 Message Size Field
*/
Xuint32 GetSize(Xuint8 *MsgBuffer)
{
	Xuint8 * Ptr = MsgBuffer;
	Ptr+=20;
	return *(Xuint32 *)Ptr;
}


/*
* Pass it a pointer to the EMAC Address
* Fills the global variable 'array' with 
* the ETHERNET Address in standard format
*/
void fill_array(Xuint8 *Ptr)    								
{
	Xuint8 mycounter;
	for(mycounter = 0 ; mycounter < 17 ; mycounter += 3)
	{
		array[mycounter+1] = map(*(Ptr) & 0xF);
		array[mycounter] = map( ( *(Ptr) & 0xF0 ) >> 4);
		Ptr++;
		if(mycounter<15) array[mycounter+2] = '-';
	}
}

/*
* Prints the EMAC Statistics
*/
void PrintEmacStats(XEmac_Stats Stats)							// for debugging
{
    xil_printf("Number of frames transmitted   		%d\n\r", Stats.XmitFrames);            
//    xil_printf("Number of bytes transmitted   		%d\n\r", Stats.XmitBytes);             
    xil_printf("Number of transmission failures due to late collisions   %d\n\r", Stats.XmitLateCollisionErrors);             
    xil_printf("Number of transmission failures due to excess collision deferrals   %d\n\r", Stats.XmitExcessDeferral);                                    
//    xil_printf("Number of transmit overrun errors   %d\n\r", Stats.XmitOverrunErrors);      
//    xil_printf("Number of transmit underrun errors  %d\n\r", Stats.XmitUnderrunErrors);      
    xil_printf("Number of frames received   		%d\n\r", Stats.RecvFrames);              
//    xil_printf("Number of bytes received   			%d\n\r", Stats.RecvBytes);               
    xil_printf("Number of frames discarded due to FCS errors   		%d\n\r", Stats.RecvFcsErrors);                                             
    xil_printf("Number of frames received with alignment errors   	%d\n\r", Stats.RecvAlignmentErrors);                                            
//    xil_printf("Number of frames discarded due to overrun errors   	%d\n\r", Stats.RecvOverrunErrors);                                                
//    xil_printf("Number of recv underrun errors   	%d\n\r", Stats.RecvUnderrunErrors);      
//    xil_printf("Number of frames missed by MAC   	%d\n\r", Stats.RecvMissedFrameErrors);   
    xil_printf("Number of frames discarded due to collisions   	%d\n\r", Stats.RecvCollisionErrors);                                           
    xil_printf("Number of frames discarded with invalid length field   %d\n\r", Stats.RecvLengthFieldErrors);                                            
//    xil_printf("Number of short frames discarded   	%d\n\r", Stats.RecvShortErrors);
//    xil_printf("Number of long frames discarded   	%d\n\r", Stats.RecvLongErrors);          
//    xil_printf("Number of DMA errors since init   	%d\n\r", Stats.DmaErrors);              
//    xil_printf("Number of FIFO errors since init   	%d\n\r", Stats.FifoErrors);             
//    xil_printf("Number of receive interrupts   		%d\n\r", Stats.RecvInterrupts);          
//    xil_printf("Number of transmit interrupts   	%d\n\r", Stats.XmitInterrupts);          
//    xil_printf("Number of MAC (device) interrupts   %d\n\r", Stats.EmacInterrupts);        
//    xil_printf("Total interrupts   					%d\n\r", Stats.TotalIntrs);             
}

/*
* Pass it a pointer to the Ethernet Frame
* 
* Prints the Layer 2 Variables
*
* Message Header Format: 	Type			 _ 2 bytes 
*							Sequence Number	 _ 4 bytes
*                           Message Length	 _ 4 bytes
*/
void Print_Message_Fields(Xuint8 *MsgBuffer, int MsgLen)  	
{
	Xuint32 mycounter;
	Xuint32 LenField;
	Xuint16 TypeofMess;
	Xuint32 FragmentPayloadLength; // since FragmentLength can be different 
							// than Message PayloadLength
	Xuint8 *MesgPtr = MsgBuffer;
	Xuint8 *TemporaryPtr = (Xuint8 *)TemporaryBuffer;
		
	xil_printf("Message Parameters\r\n");
	xil_printf("__________________\r\n");

	MesgPtr+=14;						
	TypeofMess = *(Xuint16 *)MesgPtr;
	xil_printf("Message Type Field		: %d\n\r", TypeofMess);
	
	MesgPtr+=2;

	xil_printf("Message Sequence Nb Field	: %d\n\r", *(Xuint32 *)MesgPtr);
	
	MesgPtr+=4;
	LenField = *(Xuint32 *)MesgPtr;
	xil_printf("Message Length			: %d\n\r", LenField);  
	
	MesgPtr+=4;

	if(LenField <= 1490)
		FragmentPayloadLength = LenField;   // The Frame contains the Message header (10 bytes)
											// and the whole message itself as its payload	
	   // case of fragmented message
	else
	{
		if(TypeofMess == FIRST_FRAGMENT_TYPE || TypeofMess == INTERNAL_FRAGMENT_TYPE) // frame is full
			FragmentPayloadLength = MAX_L2_PAYLOAD;  
		else if (TypeofMess == LAST_FRAGMENT_TYPE)	// last fragment of a message
		{
			if(LenField % MAX_L2_PAYLOAD == 0)		// 1490 payload size of last fragment
				FragmentPayloadLength = MAX_L2_PAYLOAD;  
			else	
				FragmentPayloadLength = (LenField % MAX_L2_PAYLOAD);
		}	
	}

		// Printing the first byte of the fragment payload
	xil_printf("Fragment Payload 1st byte: %x\n\r", *(Xuint8 *)MesgPtr);

		// Getting to the last byte of the payload	
	MesgPtr += (FragmentPayloadLength - 1);

		// Printing the last byte of the fragment payload
	xil_printf("Fragment Payload last byte: %x\n\r", *(Xuint8 *)MesgPtr);

}

/*
* Pass it a pointer to the Ethernet frame 
*
* and the MsgLen as returned by the Receive function
*
* Ethernet Header Format: 	Destination Address _ 6 bytes 
*							Source Address      _ 6 bytes
*                           Len / Type Field    _ 2 bytes
*/
void Print_Frame_Fields(Xuint8 *MsgBuffer, int MsgLen)  	
{
	Xuint8 *MesgPtr = MsgBuffer;
		
	xil_printf("Frame Parameters\r\n");
	xil_printf("________________\r\n");
	
	xil_printf("Frame Length 			: %d\r\n", MsgLen);

	fill_array(MesgPtr);		
	xil_printf("Destination MAC			: %s\r\n", array); 
	
	MesgPtr+=6;					
	
	fill_array(MesgPtr);			
	xil_printf("Source      MAC			: %s\r\n", array);
	
	MesgPtr+=6;							
									
	xil_printf("Payload Length			: %d\r\n", *(Xuint16 *)MesgPtr);	
} 
