/******************************************************************************
*
* 	2 player Network Poker using Xilinx Multimedia Boards
* 	Authors:	Lyndon Carvalho and Hin Chan
*			ECE532 - Digital Hardware 2004/2005
*			Prof. Paul Chow
*			University of Toronto
* 
* 	Description: 	Server for a 2 player network poker game between 2
*			Xilinx Multimedia Boards connected thru a hub via
*			the ethernet
*
*******************************************************************************/
           
#ifndef SINGLEMB_GLOBALVARIABLES_H
#define SINGLEMB_GLOBALVARIABLES_H

#include "SingleMB_MACAddresses.h"

/***************************** Constants Definitions ************************************/

#define XEM_MAX_FRAME_SIZE_IN_WORDS ((XEM_MAX_FRAME_SIZE / sizeof(Xuint32)) + 1)


#define TEST_1_OPTIONS		 (XEM_UNICAST_OPTION | XEM_INSERT_PAD_OPTION | \
                              XEM_INSERT_FCS_OPTION | XEM_INSERT_ADDR_OPTION | \
                              XEM_OVWRT_ADDR_OPTION)           


#define LED    0x1					// bit 0 of GPIO is connected to the LED 
 
#define INTC_INPUT_EMAC		0		// EMAC has higher priority (check add/edit cores)
#define INTC_INPUT_TIMER	1		// TIMER has lower priority

#define TIMER_COUNTER_0     0      	// Timer Counter 0 is used
#define INTC_DEVICE_ID		0


#define ACK_L2_PAYLOAD_SIZE		36
#define ACK_L1_PAYLOAD_SIZE		46
#define ACK_FRAME_SIZE			60
#define L2_HEADER_SIZE			10
#define MAX_RETRANSMIT_ATTEMPTS	10

#define ACK_MESSAGE_TYPE			1
#define NON_FRAGMENTED_MESSAGE_TYPE	0
#define FIRST_FRAGMENT_TYPE			2
#define INTERNAL_FRAGMENT_TYPE		3
#define LAST_FRAGMENT_TYPE			4
#define MAX_L2_PAYLOAD				1490


/**************************  Instance Definitions    ************************************/ 

static XGpio Gpio;             		
static XEmac Emac;					
static XIntc InterruptController; 	  
static XTmrCtr TimerCounter;

XEmac *EmacPtr;						// Initialized in Init.h		



/**************************  Buffer Variables    ******************************/ 

static Xuint32 TemporaryBuffer;	// To hold temporarily 32 bit values for alignment problems

static Xuint32 TxMessage[XEM_MAX_FRAME_SIZE_IN_WORDS + 40]; // holds fragment to send
static Xuint32 TxFrame[XEM_MAX_FRAME_SIZE_IN_WORDS];		// holds frame to send

static Xuint32 RecvBuffer[XEM_MAX_FRAME_SIZE_IN_WORDS];		// holds incoming data
static Xuint32 RecvPayload[XEM_MAX_FRAME_SIZE_IN_WORDS];	// holds incoming payload

static Xuint32 BigBuffer[XEM_MAX_FRAME_SIZE_IN_WORDS * 3];  // holds message to send

static Xuint8 AckFrame[60];									// holds the ACK to send


/**************************  Global Variables    ******************************/ 

char array[17];					// used to hold MAC addresses in standard format


Xuint32 RstVal[10] = {  0xFE600000,0xFF000000,0xFF000000, 
	      				0xFE000000 ,0xFE000000 ,0xFE000000 , 0xFD500000,
		     			0xFD000000, 0xFC700000 , 0xFC000000};

// RESET VALUE --> DELAY IN SECONDS
// 0xF0000000  --> 10 seconds approx.
// 0xF7000000  --> 5.5 seconds approx.                        
// 0xFE600000  --> 1 second approx. 
// 0xFF400000  --> 0.5 seconds approx.  



/************************** Acknowledgement Variables ***********************/

/*
*
* This structure contains all the variables to be used between
* Two Specific Nodes.
*
* This type of implementation allows us to have seperate reliable links 
*
* For a system of 'N' Communication Nodes, each single node will have 'n - 1' structures,
* each one for communicating with one neighbor. 
*
* This allows gracefull degradation of the system. If a shared communication variable between node 
* x and node y becomes invalid (each of x and y have different copies of this variable), even though this
* is unlikely to happen due to the fact that the system is designed with an error recovery algorithm, 
* only the link between x and y will be broken, while x and y would continue to talk to the rest of the 
* multiprocessor nodes. 
*  
*/

XEmac_Stats Stats;  // One Variable for the EMAC Module.


Xuint8 reload_flag;				// Changes with DIP Switch Input_this is only used in the main to manually send frames
Xuint8 Timer_Expired;			// turns to one everytime the timer expires
								// We only have one timer in the system
							  

typedef struct				/* Comm Vars Structure*/
{

Xuint32 SeqNum;					// Holds Wrapping Off Sequence Numbers of Messages

Xuint32 WaitingFrameNumber;		// Holds the Frame Seq Num we are waiting for

Xuint8 Ack_Received;   	// turns to one in case we got an ACK Message

Xuint8 ExpectMore;		// used to have proper reception of Fragmented Messages

Xuint32 RememberSeqNumReceiver;	// used to remember the sequence number of the starting sequence at the receiver

Xuint32 NbFragRecv;		// contains the previous number of fragments as part of a same message

Xuint32 MsgLength;

Xuint32 FragLength;
       
}CommunicationsVariables;


CommunicationsVariables CommVars[5]; 
				// holds 5 sets of variables for comm between board 0 to 4 in MAC terms
				
				// MAC Addresses are :
				//
				// 0  --> 06 05 04 03 02 00
				// 1  --> 06 05 04 03 02 01 
				// 2  --> 06 05 04 03 02 02
				// 3  --> 06 05 04 03 02 03
				// 4  --> 06 05 04 03 02 04
				//
			
#endif 
