/******************************************************************************
*
* 	2 player Network Poker using Xilinx Multimedia Boards
* 	Authors:	Lyndon Carvalho and Hin Chan
*			ECE532 - Digital Hardware 2004/2005
*			Prof. Paul Chow
*			University of Toronto
* 
* 	Description: 	Server for a 2 player network poker game between 2
*			Xilinx Multimedia Boards connected thru a hub via
*			the ethernet
*
*******************************************************************************/
               

#include "SingleMB_HandlerFunctions.h"
#include "SingleMB_GlobalVariables.h" 
#include "SingleMB_DebuggingFunctions.h"
#include "SingleMB_SendFunctions.h"

/*
* This function takes care of the incoming messages and writes payload into
* the receive buffers defined in GlobalVariables.h
*
* It also calls the send functions to send Acknowledge frames when 
* necessary
*/
static void FifoRecvHandler(void *CallBackRef)		
{
	Xuint32 CommVarsIndex;
	XStatus Result;
	Xuint32 FrameLen; 		
	Xuint32 writingcounter;
	Xuint8* TempAddressPtr;
	Xuint8 * WritingPtr;
	Xuint8 * ReadingPtr;
	int counter, frametype, msgtype, playernum, i;
	
	XIntc_Disable(&InterruptController, INTC_INPUT_EMAC);

	FrameLen = XEM_MAX_FRAME_SIZE;	
	Result = XEmac_FifoRecv((XEmac *)CallBackRef, RecvBuffer, &FrameLen); 
	
	if (Result != XST_SUCCESS)						// error in reception
	{
		xil_printf("Fifo Receive Error\n\r");
		
		XIntc_Enable(&InterruptController, INTC_INPUT_EMAC);		
		return;								
	}
	else											// valid message or Ack
	{	
		TempAddressPtr = (Xuint8 *)RecvBuffer + XEM_MAC_ADDR_SIZE; // get the source address pointer
		CommVarsIndex = GetIndex((Xuint8 *)TempAddressPtr);

		if(GetType((Xuint8 *)RecvBuffer) == ACK_MESSAGE_TYPE  && 
			GetSeqNum((Xuint8 *)RecvBuffer) == CommVars[CommVarsIndex].SeqNum)    
													// Received an ACK for previous message sent
		{		
				XTmrCtr_Stop(&TimerCounter, TIMER_COUNTER_0);	    
				XIntc_Disable(&InterruptController, INTC_INPUT_TIMER);						
								
				CommVars[CommVarsIndex].Ack_Received =  1; 
		}

		if((GetType((Xuint8 *)RecvBuffer) == NON_FRAGMENTED_MESSAGE_TYPE || GetType((Xuint8 *)RecvBuffer) == FIRST_FRAGMENT_TYPE) 
			&& CommVars[CommVarsIndex].ExpectMore == 1) // error has happened in the last message transmission
		{																				
		CommVars[CommVarsIndex].WaitingFrameNumber = CommVars[CommVarsIndex].RememberSeqNumReceiver;	
														// Recover from one lost frame in Fragmented message
														// whole message is discarded
														// sequence number is recovered as it was before reception 
														// of first fragment
		
		/***************************************************************************************
		*  User Code : fluch the user's buffers filled with previous fragments of same message 
		****************************************************************************************/
	
		/*example*/
		xil_printf("Flushing my buffers !!\n\r");

		/*********************
		*  End of User Code 
		**********************/
	
         

		}

		if(GetType((Xuint8 *)RecvBuffer) != ACK_MESSAGE_TYPE)			
		{
				
			
			/******* Recovery Algorithm ****/

			//	if we were receiving a fragmented message, in case our last ack was lost, 
			//  we have an incremented sequence number whereas the sender does not
			//	so if we get a sequence numbered frame as this remember value, we know that our last ack was lost
			//  so there is a discrepency between our sequence number and that of the sender
			//  to solve this we simply reset our waiting frame number to this value and we receive a new frame

			if(GetSeqNum((Xuint8 *)RecvBuffer) == CommVars[CommVarsIndex].RememberSeqNumReceiver)	// proper incoming number
			{
				CommVars[CommVarsIndex].WaitingFrameNumber = CommVars[CommVarsIndex].RememberSeqNumReceiver;
				//xil_printf("Recovering  !!");
			}

			/*******************************/



			if(GetSeqNum((Xuint8 *)RecvBuffer) == CommVars[CommVarsIndex].WaitingFrameNumber)	// proper incoming number
			{		
				Send_Ack_Message(RecvBuffer);   						// Send an ACK 
	
				if(GetType((Xuint8 *)RecvBuffer) == FIRST_FRAGMENT_TYPE) 
				{
					CommVars[CommVarsIndex].ExpectMore = 1;	
					CommVars[CommVarsIndex].NbFragRecv = 1;
					// we are expecting more frames
					
					CommVars[CommVarsIndex].FragLength = MAX_L2_PAYLOAD; // 1490 bytes

					CommVars[CommVarsIndex].RememberSeqNumReceiver = CommVars[CommVarsIndex].WaitingFrameNumber;	
					// for recovery in case one of the frames of the message failed

				/* Writing the frame payload into RecvPayload buffer that can hold it all */
				
					WritingPtr = (Xuint8 *)RecvPayload;			// Location where to write payload
					ReadingPtr = (Xuint8 *)RecvBuffer;			// location where to read payload
			
					ReadingPtr += 24;							// getting to message payload from fragment frame
					CommVars[CommVarsIndex].MsgLength =   GetSize(&RecvBuffer);
	
					for(writingcounter = 0 ; writingcounter < MAX_L2_PAYLOAD ; writingcounter++)
					{
						*WritingPtr++ = *ReadingPtr++;
					}
				
						/***************************************************************************************
						*  User Code : Copy the payload from "RecvPayload" Buffer into user buffer 
						****************************************************************************************/
					// Fragment Payload length is in : CommVars[CommVarsIndex].FragLength
					// Indication of the source address is in : CommVarsIndex
					// Total Message Payload length is in : CommVars[CommVarsIndex].MsgLength
					// Number of fragments received (with this one) : 	CommVars[CommVarsIndex].NbFragRecv				
					
					/*Example print statements*/
						xil_printf("\nType			: %d\n\r", FIRST_FRAGMENT_TYPE);
						xil_printf("Index			: %d\n\r", CommVarsIndex);
						xil_printf("Fragment Length : %d\n\r", CommVars[CommVarsIndex].FragLength);
						xil_printf("Message Length	: %d\n\r", CommVars[CommVarsIndex].MsgLength);
						xil_printf("Nb Frag Received: %d\n\r", CommVars[CommVarsIndex].NbFragRecv);


						/*********************
						*  End of User Code 
						CommVars[CommVarsIndex].MsgLength =   GetSize(&RecvBuffer);
						**********************/			
				}									

				CommVars[CommVarsIndex].WaitingFrameNumber = ( CommVars[CommVarsIndex].WaitingFrameNumber + 1 ) % 0xFFFFFFFF;


				if(GetType((Xuint8 *)RecvBuffer) == NON_FRAGMENTED_MESSAGE_TYPE)				// non fragmented message encapsulated in one frame
				{
					CommVars[CommVarsIndex].ExpectMore = 0;
					CommVars[CommVarsIndex].NbFragRecv = 1;

					WritingPtr = (Xuint8 *)RecvPayload;			// Location where to write payload
					ReadingPtr = (Xuint8 *)RecvBuffer;			// location where to read payload
			
					ReadingPtr += 24;							// getting to message payload from fragment frame
					CommVars[CommVarsIndex].MsgLength =   GetSize(&RecvBuffer);
					CommVars[CommVarsIndex].FragLength =   GetSize(&RecvBuffer);


					for(writingcounter = 0 ; writingcounter <  CommVars[CommVarsIndex].MsgLength ; writingcounter++)
					{
						*WritingPtr++ = *ReadingPtr++;
					}
						/***************************************************************************************
						*  User Code : Copy the payload from "RecvPayload" Buffer into user buffer 
						****************************************************************************************/
					// Fragment Payload length is in : CommVars[CommVarsIndex].FragLength
					// Indication of the source address is in : CommVarsIndex
					// Total Message Payload length is in : CommVars[CommVarsIndex].MsgLength
					// Number of fragments received (with this one) : 	CommVars[CommVarsIndex].NbFragRecv				
					
					/*Example print statements*/
						/*xil_printf("\nType			: %d\n\r", NON_FRAGMENTED_MESSAGE_TYPE);
						xil_printf("Index			: %d\n\r", CommVarsIndex);
						xil_printf("Fragment Length : %d\n\r", CommVars[CommVarsIndex].FragLength);
						xil_printf("Message Length	: %d\n\r", CommVars[CommVarsIndex].MsgLength);
						xil_printf("Nb Frag Received: %d\n\r", CommVars[CommVarsIndex].NbFragRecv);*/

					/************* Determine frame type ***********************/
					ReadingPtr = (Xuint8 *)RecvPayload;
					(Xuint8) frametype = * (Xuint8 *) ReadingPtr++;
					switch (frametype) {
					case (Xuint8) 1:
						// cards frame received
						for(counter = 0 ; counter < numplayers*2+5 ; counter++) {
							(Xuint8) (valHands[counter]) = *(Xuint8 *) ReadingPtr;
							ReadingPtr ++;
		
							(Xuint8) (suitHands[counter]) = *(Xuint8 *) ReadingPtr;
							ReadingPtr ++;
						} 
						//updatehand = 1;
						break;
					case (Xuint8) 2:
						// cash and pot frame received
						for(counter = 0 ; counter < numplayers; counter++) {
							(Xuint8) cash[counter] = *(Xuint8 *) ReadingPtr;
							ReadingPtr++;
							//printf("Cash[%d] = %d\n\r",counter, cash[counter]);
						}
						(Xuint8) pot = *(Xuint8 *) ReadingPtr;
						updatehand = 1;
						break;
					case (Xuint8) 3:
						// turn (flop, 4th street, river) frame received
						oldturn = turn;
						turn = *(Xuint8 *) ReadingPtr;
						printf("Turn received: %d\n\r", turn);
						newturn = 1;
						break;
					case (Xuint8) 4:
						// Dobet frame received
						maxcurrentbet = *(Xuint8 *) ReadingPtr;
						printf("Maxcurrentbet: %d\n\r", maxcurrentbet);
						dobet = 1;
						break;
					case (Xuint8) 5:
						// Bet status frame received (check, call, raise, fold)
						playerbet = *(Xuint8 *) ReadingPtr;
						if (tempbet == 255) {
							tempbet = -1;
						}
						dobet = 1;
						break;
					case (Xuint8) 6:
						// Status frame received
						(Xuint8) msgtype = * (Xuint8 *) ReadingPtr++;
						(Xuint8) playernum = * (Xuint8 *) ReadingPtr++;
						switch (msgtype){
						case 0:
							printf("Player %d calls/checks\n\r", playernum);
							drawText("CALL\n", BLACK, stackRow[((playernum-1)+numplayers-(playerid-1))%numplayers]+4, stackCol[((playernum-1)+numplayers-(playerid-1))%numplayers]);
							bet[(playernum-1)]=maxcurrentbet;
							break;
						case 1:
							printf("Player %d raises %d\n\r", playernum, * (Xuint8 *) ReadingPtr);
							drawText("RAISE\n", BLACK, stackRow[((playernum-1)+numplayers-(playerid-1))%numplayers]+4, stackCol[((playernum-1)+numplayers-(playerid-1))%numplayers]);
							drawBigChar(DOLLARSIGN, BLACK, stackRow[((playernum-1)+numplayers-(playerid-1))%numplayers]+6, stackCol[((playernum-1)+numplayers-(playerid-1))%numplayers]); 
							drawInt( (* (Xuint8 *) ReadingPtr), BLACK, stackRow[((playernum-1)+numplayers-(playerid-1))%numplayers]+6, stackCol[((playernum-1)+numplayers-(playerid-1))%numplayers]+2); 
							bet[(playernum-1)]=maxcurrentbet+(* (Xuint8 *) ReadingPtr);
							break;
						case 2:
							printf("Player %d wins %d\n\r", playernum, * (Xuint8 *) ReadingPtr);
							turn = oldturn;
							for (i=0;i<numplayers;i++) {
								bet[i] = 0;
							}
							printHands(turn);
							drawText("WIN\n", BLACK, stackRow[((playernum-1)+numplayers-(playerid-1))%numplayers]+4, stackCol[((playernum-1)+numplayers-(playerid-1))%numplayers]);
							drawBigChar(DOLLARSIGN, BLACK, stackRow[((playernum-1)+numplayers-(playerid-1))%numplayers]+6, stackCol[((playernum-1)+numplayers-(playerid-1))%numplayers]); 
							drawInt((* (Xuint8 *) ReadingPtr), BLACK, stackRow[((playernum-1)+numplayers-(playerid-1))%numplayers]+6, stackCol[((playernum-1)+numplayers-(playerid-1))%numplayers]+2); 
							turn = 0;
							break;
						case 3:
							printf("Player %d folds\n\r", playernum);
							drawText("FOLD\n", BLACK, stackRow[((playernum-1)+numplayers-(playerid-1))%numplayers]+4, stackCol[((playernum-1)+numplayers-(playerid-1))%numplayers]);
							break;
						case 4:
							quit = 1;
							break;
						}
						break;
						
					case (Xuint8) 7:
						// connection request frame received from client
						connect = 1;
						break;
					
						
					}

						/*********************
						*  End of User Code 
						**********************/
					
				
				}
				
				if(GetType((Xuint8 *)RecvBuffer) == INTERNAL_FRAGMENT_TYPE)				// Frame in the middle of the sequence of frames of a Frag. Messg.
				{
					CommVars[CommVarsIndex].NbFragRecv ++; 	
					CommVars[CommVarsIndex].ExpectMore = 1;		
				
					ReadingPtr = (Xuint8 *)RecvBuffer;			// location where to read payload
			
					ReadingPtr += 24;
					WritingPtr = (Xuint8 *)RecvPayload;			// Location where to write payload

					CommVars[CommVarsIndex].MsgLength =   GetSize(&RecvBuffer);
					CommVars[CommVarsIndex].FragLength =   MAX_L2_PAYLOAD;
					

					for(writingcounter = 0 ; writingcounter < MAX_L2_PAYLOAD ; writingcounter++)
					{
						*WritingPtr++ = *ReadingPtr++;    // Writing Ptr is still valid from the last time
					}

						/***************************************************************************************
						*  User Code : Copy the payload from "RecvPayload" Buffer into user buffer 
						****************************************************************************************/
					// Fragment Payload length is in : CommVars[CommVarsIndex].FragLength
					// Indication of the source address is in : CommVarsIndex
					// Total Message Payload length is in : CommVars[CommVarsIndex].MsgLength
					// Number of fragments received (with this one) : 	CommVars[CommVarsIndex].NbFragRecv				
					
					/*Example print statements*/
						xil_printf("\nType			: %d\n\r", INTERNAL_FRAGMENT_TYPE);
						xil_printf("Index			: %d\n\r", CommVarsIndex);
						xil_printf("Fragment Length : %d\n\r", CommVars[CommVarsIndex].FragLength);
						xil_printf("Message Length	: %d\n\r", CommVars[CommVarsIndex].MsgLength);
						xil_printf("Nb Frag Received: %d\n\r", CommVars[CommVarsIndex].NbFragRecv);


						/*********************
						*  End of User Code 
						**********************/
				
				}

				if(GetType((Xuint8 *)RecvBuffer) == LAST_FRAGMENT_TYPE)				// last frame of a Fragmented Message
				{
					CommVars[CommVarsIndex].NbFragRecv++; // we don't need it anymore
					CommVars[CommVarsIndex].ExpectMore = 0;	

				
					CommVars[CommVarsIndex].MsgLength = GetSize(&RecvBuffer);
			
					if(CommVars[CommVarsIndex].MsgLength % MAX_L2_PAYLOAD == 0)
						CommVars[CommVarsIndex].FragLength = MAX_L2_PAYLOAD;
					else
						CommVars[CommVarsIndex].FragLength = CommVars[CommVarsIndex].MsgLength % MAX_L2_PAYLOAD;

					ReadingPtr = (Xuint8 *)RecvBuffer;			// location where to read payload
					ReadingPtr += 24;
					WritingPtr = (Xuint8 *)RecvPayload;			// Location where to write payload

					for(writingcounter = 0 ; writingcounter < CommVars[CommVarsIndex].FragLength ; writingcounter++)
					{
						*WritingPtr++ = *ReadingPtr++;    // Writing Ptr is still valid from the last time
					}
			
				
				
						/***************************************************************************************
						*  User Code : Copy the payload from "RecvPayload" Buffer into user buffer 
						****************************************************************************************/
					// Fragment Payload length is in : CommVars[CommVarsIndex].FragLength
					// Indication of the source address is in : CommVarsIndex
					// Total Message Payload length is in : CommVars[CommVarsIndex].MsgLength
					// Number of fragments received (with this one) : 	CommVars[CommVarsIndex].NbFragRecv				
					
					/*Example print statements*/
						xil_printf("\nType			: %d\n\r", LAST_FRAGMENT_TYPE);
						xil_printf("Index			: %d\n\r", CommVarsIndex);
						xil_printf("Fragment Length : %d\n\r", CommVars[CommVarsIndex].FragLength);
						xil_printf("Message Length	: %d\n\r", CommVars[CommVarsIndex].MsgLength);
						xil_printf("Nb Frag Received: %d\n\r", CommVars[CommVarsIndex].NbFragRecv);


						/*********************
						*  End of User Code 
						**********************/

				
				
				}
			}
			else if(GetSeqNum((Xuint8 *)RecvBuffer) == CommVars[CommVarsIndex].WaitingFrameNumber - 1)
			{	
					Send_Ack_Message(RecvBuffer);   				
					// Send an ACK Message (our previous ack was probably lost
			}	
		}

	} 


//	Print_Frame_Fields(RecvBuffer, FrameLen); 
//	Print_Message_Fields(RecvBuffer, FrameLen - 18); 

	XIntc_Enable(&InterruptController, INTC_INPUT_EMAC);
}



/*
* Sets Timer_Expired to 1 when timer counter wraps around
* 
* This value is used in the SendReliably function as an indicator  
* that we did not receive an ACK in the acceptable delay
*
* It is disabled not to generate new interrupts.
* We enable it only when we start counting after a send.
*
* CallBackRef is a pointer to the XTmrCtr
*/
static void TimerCounterHandler(void *CallBackRef) 
{	
	Timer_Expired = 1;
    xil_printf("ACK Time Exp.\n\r");
	
	XIntc_Disable(&InterruptController, INTC_INPUT_TIMER);	      
}


/*
* Checks for errors
*/
static void FifoSendHandler(void *CallBackRef)				
{
    XEmac_GetStats((XEmac *)CallBackRef, &Stats);
    
	if (Stats.XmitLateCollisionErrors || Stats.XmitExcessDeferral)
    {
		xil_printf("Late Collision Number : %d\n\r", Stats.XmitLateCollisionErrors);
		xil_printf("Late Deferrals Number : %d\n\r", Stats.XmitExcessDeferral);
		xil_printf("Error in FIFO Sending !!\n\r");
		PrintEmacStats(Stats);
    }

	XEmac_ClearStats((XEmac *)CallBackRef);
}


/*
* Called in case of Errors to reset the system
*/ 
static void ErrorHandler(void *CallBackRef, XStatus Code)	
{
	xil_printf("Starting FIFO Error Handler\n\r");
    if (Code == XST_RESET_ERROR)
    {
        XEmac_Reset((XEmac *)CallBackRef);									// Reset EMAC

        (void)XEmac_SetMacAddress((XEmac *)CallBackRef, LocalAddress);		// SET MAC ADDRESS
        (void)XEmac_SetOptions((XEmac *)CallBackRef, TEST_1_OPTIONS);		// SET OPTIONS

        (void)XEmac_Start((XEmac *)CallBackRef);							// Start EMAC
    }
	xil_printf("Exiting FIFO Error Handler\n\r");
}
