/******************************************************************************
*
* 	2 player Network Poker using Xilinx Multimedia Boards
* 	Authors:	Lyndon Carvalho and Hin Chan
*			ECE532 - Digital Hardware 2004/2005
*			Prof. Paul Chow
*			University of Toronto
* 
* 	Description: 	Server for a 2 player network poker game between 2
*			Xilinx Multimedia Boards connected thru a hub via
*			the ethernet
*
*******************************************************************************/

#ifndef SINGLEMB_SENDFUNCTIONS_H
#define SINGLEMB_SENDFUNCTIONS_H

#include "SingleMB_GlobalVariables.h"
#include "SingleMB_DebuggingFunctions.h"

/*
* Fills the Ethernet Header and the Payload into TxFrame Buffer
* Source Address automatically included by PHY
*
* returns XST_SUCCESS or XST_FAILURE for just sending the frame
*
* Further reliability should be implemented seperatly
*
* Ethernet Header Format: 	Destination Address _ 6 bytes 
*							Source Address      _ 6 bytes
*                           Len / Type Field    _ 2 bytes
*/
static XStatus SendFrame(XEmac *EmacPtr, Xuint32 FramePayloadSize, Xuint8* InputBuffer,	
                         Xuint8 *DestAddress);

/*
* Pass it a pointer to the message we want to send an ACK for
*
* Destination MAC address for the ACK determined automatically
*
* NOTE: this will send an ACK only for frames that are non ACK Messages
*       The check for this is in the 'if' statement
*
* Returns XST_SUCCESS or XST_FAILURE
*
* XST_FAILURE	if we failed to send
*				or if we tried to send an ACK for an ACK
*/
XStatus Send_Ack_Message(Xuint8 *MsgBuffer);  		

/*
* Fills the Layer 2 Header and the Payload into TxMessage Buffer
* It calls the SendFrame to fill the Ethernet header and send the frame
*
* Note: the messages sent by this function can only be <= 1490 bytes in length
* returns XST_SUCCESS or XST_FAILURE for just sending the frame
*
* Further reliability should be implemented seperatly
*
*  Message Header Format: 	Type			 _ 2 bytes 
*							Sequence Number	 _ 4 bytes
*                           Message Length	 _ 4 bytes
*/
static XStatus SendMessage(Xuint32 MessagePayloadSz, Xuint8* InputBuffer,	
                         Xuint8 *DestAddress,  Xuint16 TypeofMessage);


/*
* Uses send message to send the payload passed through the pointer InputBuffer
* 
* tried to send it 10 times after which it returns XST_FAILURE
* returns XST_SUCCESS if an ACK is received for this message
*
* Uses different waiting times for resetting the timer.
* Once the timer expires it sets Timer_Expired = 1 
*
* Ack_Received is set to 1 by the receive handler function
*/
static XStatus SendReliably(Xuint32 MessagePayloadSz, Xuint8 *InputBuffer, Xuint8 *DestAddress, Xuint16 TypeofMessage);



/*
* Fragments the content pointed to by input buffer and sends the fragmented message across successive
* maximum payload 1490 bytes frames.
*
* In case one of the messages failed to arrive reliably to the receiver, 
* the sequence numbers are reset so what they were before starting to send the message
*
* a very unlikely deadlock case is if the last ack that should be received by this sender failed to reach
* us 10 times. In this case, the sender would reset its sequence numbers, whereas the receiver would have the waiting sequence numbers
* after the last received message.
*
* Future Work: Deal properly with this case. Maybe send some special type of message to have like a sequence number handshake
* or agreement.
*/
static XStatus Fragment_and_Send_Reliably(Xuint32 MessagePayloadSz, Xuint8 *InputBuffer, Xuint8 *DestAddress); 


#endif
