/******************************************************************************
*
* 	2 player Network Poker using Xilinx Multimedia Boards
* 	Authors:	Lyndon Carvalho and Hin Chan
*			ECE532 - Digital Hardware 2004/2005
*			Prof. Paul Chow
*			University of Toronto
* 
* 	Description: 	Client for a 2 player network poker game between 2
*			Xilinx Multimedia Boards connected thru a hub via
*			the ethernet
*
*******************************************************************************/
                            
/*****************************  Include Files *********************************/

#include <stdio.h>
#include <math.h>
#include <stdlib.h>

#include "xemac.h"		       	// Ethernet Module             	       
#include "xparameters.h"              			                              
#include "xstatus.h"                                                                               
                                                           
#include "mb_interface.h"       // MicroBlaze  
#include "xintc.h"       		// for interrupt control
#include "xgpio.h"    			// for the switch  
#include "xtmrctr.h"			// To implement delayed frame retransmissions 

#include "globals.h"
#include "display.h"

#include "SingleMB_MACAddresses.h"				// contains the MAC Address Definitions and some functions
#include "SingleMB_GlobalVariables.h" 			// contains the global variables shared among the 5 files
#include "SingleMB_HandlerFunctions.h" 			// contains handler functions 
#include "SingleMB_SendFunctions.h"				// contains the send functions of frame and message layers
#include "SingleMB_InitializationFunctions.h"	// contains the initialization functions
#include "SingleMB_DebuggingFunctions.h"		// contains the functions to display frame 
												// and message headers and payload...

#include "SingleMB_MACAddresses.c"				// contains the MAC Address Definitions and some functions
#include "SingleMB_HandlerFunctions.c" 			// contains handler functions 
#include "SingleMB_SendFunctions.c"				// contains the send functions of frame and message layers
#include "SingleMB_InitializationFunctions.c"	// contains the initialization functions
#include "SingleMB_DebuggingFunctions.c"		// contains the functions to display frame and message headers and payload...

#include "display.c"
#include "printHands.c"
#include "send.c"
#include "betting.c"

/*********************************    MAIN FUNCTION      *******************************/

int main()       
{	     
	/* Definitions */
    
	Xuint32 counter;        
	Xuint32 debouncing;  
	Xuint8 * TempAddressPtr;
	int playerbet;
	int i;

	playerid = 2;
	quit = 0;

	/* Initializations */
	Initialize_Parameters();	// for EMAC and TIMERCOUNTER and INTERRUPTS and GPIO
	/*                 */

	sendConnect();

	updatehand = 0;
	while(!updatehand) { //wait for initial cash
	}
	updatehand = 0;
	turn = 0;
	dobet = 0;
	amsmallblind = 1;

    while(1) {  
		if (updatehand == 1) { //print new status when new turn or new cash received
			printHands(turn);
			updatehand = 0;
		}
		if (newturn == 1) {
			//printf("turn: %d\n\r", turn);
			if (turn == 0) {	//initialize bets for big and small blinds
				if (amsmallblind) {
					bet[playerid-1]=1;
					bet[playerid%numplayers]=2;
					amsmallblind = 0;
					maxcurrentbet = 2;
				} else {
					bet[playerid-1]=2;
					bet[(playerid)%numplayers]=1;
					amsmallblind = 1;
					maxcurrentbet = 2;
				}
			} else {		//round over
				if (turn == 5) {
					turn = oldturn;
				}
			
				for(i = 0; i<numplayers;i++) {	//reset bettings
					bet[i] = 0;
				}
				maxcurrentbet = 0;
			}
			if (turn < 4) {
				printHands(turn);
			}
			newturn = 0;
		}
		if (dobet == 1) {	//received doBet frame
			playerbet = getBet(playerid-1);
			if (playerbet != -1) {
				bet[playerid-1] += playerbet;
			}
			sendBet(playerbet);
			dobet = 0;
		}

		if (quit == 1) {	//over
			printf("GAME OVER\n\r");
			drawText("GAME OVER\n", BLACK, HEIGHT/2, WIDTH/2-8);
			return 0;
		}

	}							// end of while(1)	
	return 0;
}

/*********************************************************************************************/