/******************************************************************************
*
*	Simple Reliable Communication System over Ethernet _ Single MicroBlaze System 
*	
*	Definitions of some functions for debugging and displaying frame content
*	and headers
* 
* 	Author: 	Patrick E. Akl  
*           	American University of Beirut
*				August 2004
*			 	
*	For any comments, suggestions or bug discovery, please contact me at the following
*	email address : patrickakl@hotmail.com
*					
*	or contact Christopher-John Comis (University of Toronto)
*   at the following email address:
*					comis@eecg.toronto.edu
*
*******************************************************************************/
               
#ifndef SINGLEMB_DEBUGGINGFUNCTIONS_H 
#define SINGLEMB_DEBUGGINGFUNCTIONS_H

#include "SingleMB_GlobalVariables.h"

/*
*   returns the character equivalent of an integer
*/
char map(int x);
 

/*
* Pass it a Pointer to the start of the Ethernet Header
* Returns the Layer 2 Type Field
*/
Xuint16 GetType(Xuint8 *MsgBuffer);

/*
* Pass it a Pointer to the start of the Ethernet Header
* Returns the Layer 2 Sequence Number Field
*/
Xuint32 GetSeqNum(Xuint8 *MsgBuffer);

/*
* Pass it a Pointer to the start of the Ethernet Header
* Returns the Layer 2 Message Size Field
*/
Xuint32 GetSize(Xuint8 *MsgBuffer);

/*
* Pass it a pointer to the EMAC Address
* Fills the global variable 'array' with 
* the ETHERNET Address in standard format
*/
void fill_array(Xuint8 *Ptr);

/*
* Prints the EMAC Statistics
*/
void PrintEmacStats(XEmac_Stats Stats);

/*
* Pass it a pointer to the Ethernet Frame
* 
* Prints the Layer 2 Variables
*
* Message Header Format: 	Type			 _ 2 bytes 
*							Sequence Number	 _ 4 bytes
*                           Message Length	 _ 4 bytes
*/
void Print_Message_Fields(Xuint8 *MsgBuffer, int MsgLen);

/*
* Pass it a pointer to the Ethernet frame 
*
* and the MsgLen as returned by the Receive function
*
* Ethernet Header Format: 	Destination Address _ 6 bytes 
*							Source Address      _ 6 bytes
*                           Len / Type Field    _ 2 bytes
*/
void Print_Frame_Fields(Xuint8 *MsgBuffer, int MsgLen);

#endif
                          