/******************************************************************************
*
*	Simple Reliable Communication System over Ethernet _ Single MicroBlaze System 
*	
*	Definitions of the handler functions
* 
* 	Author: 	Patrick E. Akl  
*           	American University of Beirut
*				August 2004
*			 	
*	For any comments, suggestions or bug discovery, please contact me at the following
*	email address : patrickakl@hotmail.com
*					
*	or contact Christopher-John Comis (University of Toronto)
*   at the following email address:
*					comis@eecg.toronto.edu
*
*******************************************************************************/
               
#ifndef SINGLEMB_HANDLERFUNCTIONS_H
#define SINGLEMB_HANDLERFUNCTIONS_H

#include "SingleMB_GlobalVariables.h"

#include "SingleMB_GlobalVariables.h" 
#include "SingleMB_DebuggingFunctions.h"
#include "SingleMB_SendFunctions.h"

/*
* This function takes care of the incoming messages and writes payload into
* the receive buffers defined in GlobalVariables.h
*
* It also calls the send functions to send Acknowledge frames when 
* necessary
*/
static void FifoRecvHandler(void *CallBackRef);


/*
* Sets Timer_Expired to 1 when timer counter wraps around
* 
* This value is used in the SendReliably function as an indicator  
* that we did not receive an ACK in the acceptable delay
*
* It is disabled not to generate new interrupts.
* We enable it only when we start counting after a send.
*
* CallBackRef is a pointer to the XTmrCtr
*/
static void TimerCounterHandler(void *CallBackRef);

/*
* Checks for errors
*/
static void FifoSendHandler(void *CallBackRef);

/*
* Called in case of Errors to reset the system
*/ 
static void ErrorHandler(void *CallBackRef, XStatus Code);
	
#endif