/******************************************************************************
*
*	Simple Reliable Communication System over Ethernet _ Single MicroBlaze System 
*	
*	MAC Addresses definitions and selection of the local address
*	Definition for some MAC Address operation functions
* 
* 	Author: 	Patrick E. Akl  
*           	American University of Beirut
*				August 2004
*			 	
*	For any comments, suggestions or bug discovery, please contact me at the following
*	email address : patrickakl@hotmail.com
*					
*	or contact Christopher-John Comis (University of Toronto)
*   at the following email address:
*					comis@eecg.toronto.edu
*
*******************************************************************************/
           
#include "SingleMB_MACAddresses.h"

/*
* This function takes a pointer to two MAC Addresses and 
* compares them
* returns XST_SUCCESS if they match
*/
XStatus CompareMACAddresses(Xuint8 *MAC1, Xuint8 *MAC2)
{
	Xuint8 cnt;
	Xuint8 *ptr1 = MAC1;
	Xuint8 *ptr2 = MAC2;

	for(cnt = 0 ; cnt < XEM_MAC_ADDR_SIZE ; cnt++)
	{
		if( *(Xuint8 *)ptr1  !=   *(Xuint8 *)ptr2 )
			return XST_FAILURE;
	
		ptr1 ++;
		ptr2 ++;

	}
	return XST_SUCCESS;
}

/*
* This function returns the appropriate index for the CommVars Array
* according to the MACAddress Field passed to it
* returns -1 for FAILURE
*/
Xuint32 GetIndex(Xuint8 *MACAddress)
{
	if(CompareMACAddresses((Xuint8*)Address0, (Xuint8 *)MACAddress) == XST_SUCCESS )
	{
		return 0 ;
	}
	else if(CompareMACAddresses((Xuint8*)Address1, (Xuint8 *)MACAddress) == XST_SUCCESS )
	{
		return 1 ;
	}
	else if(CompareMACAddresses((Xuint8*)Address2, (Xuint8 *)MACAddress) == XST_SUCCESS )
	{
		return 2 ;
	}
	else if(CompareMACAddresses((Xuint8*)Address3, (Xuint8 *)MACAddress) == XST_SUCCESS )
	{
		return 3 ;
	}
	else if(CompareMACAddresses((Xuint8*)Address4, (Xuint8 *)MACAddress) == XST_SUCCESS )
	{
		return 4 ;
	}
	else
		return -1;   // for errors

}



