/******************************************************************************
*
*	Simple Network Sniffer 
*
*	This code Setup a board to act in promiscuous mode to monitor the network
* 	transactions. It doesn't affect the network since it is just listening to the
*	frames exchanged on common media and displaying some frame and message layer 
*	variables read from the frame.
*
*	NOTE 1:
*	The user can select two modes of display using the DIP Switch. One mode is heavy and
*	displays all the fields in the frame and message header as well as the first and last 
*	bytes of the data payload for data consistency verifications
*	The second mode will simply display the type of the message as well as the destination
*	and source MAC Addresses.
*
*	Types of Messages :
*    
*	0 _ Non Fragmented Message
*	1 _ ACK Message 
*	2 _	First Fragment Frame
*	3 _	Internal Fragment Frame
*	4 _	Last Fragment Frame
*
*	NOTE 2:
*	This Simple Network Sniffer would not work on a Switch since the switch would direct
*	the frames to their destination boards only. Hence this sniffer would only be used on a 
*	HUB Based Network System (Or on any other shared media Network System)
*
*
* 	Author: 	Patrick E. Akl  
*           	American University of Beirut
*				August 2004
*			 	
*	For any comments, suggestions or bug discovery, please contact me at the following
*	email address : patrickakl@hotmail.com
*					
*	or contact Christopher-John Comis (University of Toronto)
*   at the following email address:
*					comis@eecg.toronto.edu
*
*******************************************************************************/

/*****************************  Include Files *********************************/
     
#include "xemac.h"		       	// Ethernet              	       
#include "xparameters.h"               			                              
#include "xstatus.h"                                                                             
                                          
#include "mb_interface.h"       // MicroBlaze  
#include "xintc.h"       		// for interrupt control
#include "xgpio.h"    			// for the switch  

#include "Sniffer_GlobalVariables.h" 	// contains the global variables shared among the 5 files
#include "Sniffer_Handlers.h"			// contains the handlers functions
#include "Sniffer_DebugFunctions.h" 	// contains functions for debugging using UArt
#include "Sniffer_Initializations.h"	// contains the functions that initialize our instances

#include "Sniffer_Handlers.c"			// contains the handlers functions
#include "Sniffer_DebugFunctions.c" 	// contains functions for debugging using UArt
#include "Sniffer_Initializations.c"	// contains the functions that initialize our instances
     
/*********************************    MAIN FUNCTION      *******************************/
 
int main()       
{	     
	xil_printf("\n\n\n\n\n\n\r");

	/* Initializations ** EMAC and INTERRUPTS and GPIO */
	Initialize_Parameters();	
	
	xil_printf("\n\rNetwork Transactions Sniffer Node\n\r");
	xil_printf("_________________________________\n\n\n\r");

	/* Loop to keep sniffing the network */ 
    while (1) 
    {
		if(XGpio_DiscreteRead(&Gpio) >= 2)
	    	{	
			for(debouncing = 0 ; debouncing < 100 ; debouncing ++);
					
			if(XGpio_DiscreteRead(&Gpio) >= 2)
			{
					if(DegreeofInformation == 0)
					{
						DegreeofInformation = 1;				

						xil_printf("Heavy Monitoring Mode\n\n\r"); 
					}	   	
				}  
			}
		else if (XGpio_DiscreteRead(&Gpio) < 2)	    
		 	{
				for(debouncing = 0 ; debouncing < 100 ; debouncing ++);
					
				if(XGpio_DiscreteRead(&Gpio) < 2)		
				{
					if(DegreeofInformation == 1)
					{
						DegreeofInformation = 0;				

						xil_printf("Light Monitoring Mode\n\n\r");
					}	    	
				}	
	  		}												
    }								   				
	 
	return 0;          
}  

