/******************************************************************************
*
*	Simple Network Sniffer __ Debug Tools 
*	
*	This contains some functions used to parse the frame and
*	display the various fields in the frame
*
* 	Author: 	Patrick E. Akl  
*           	American University of Beirut
*				August 2004
*			 	
*	For any comments, suggestions or bug discovery, please contact me at the following
*	email address : patrickakl@hotmail.com
*					
*	or contact Christopher-John Comis (University of Toronto)
*   at the following email address:
*					comis@eecg.toronto.edu
*
*******************************************************************************/

#include "Sniffer_GlobalVariables.h" 

/*
*   returns the character equivalent of an integer
*/
char map(int x)      
{
	switch(x)
	{
	case 0:
		return '0';
	case 1:
		return '1';
	case 2:
		return '2';
	case 3:
		return '3';
	case 4:
		return '4';
	case 5:
		return '5';
	case 6:
		return '6';
	case 7:
		return '7';
	case 8:
		return '8';
	case 9:
		return '9';
	case 10:
		return 'A';
	case 11:
		return 'B';
	case 12:
		return 'C';
	case 13:
		return 'D';
	case 14:
		return 'E';
	case 15:
		return 'F';	
	}
}
 

/*
* Pass it a Pointer to the start of the Ethernet Header
* Returns the Layer 2 Type Field
*/
Xuint16 GetType(Xuint8 *MsgBuffer)
{
	Xuint8 * Ptr = MsgBuffer;
	Ptr+=14;
	return *(Xuint16 *)Ptr;
}

/*
* Pass it a Pointer to the start of the Ethernet Header
* Returns the Layer 2 Sequence Number Field
*/
Xuint32 GetSeqNum(Xuint8 *MsgBuffer)
{
	Xuint8 * Ptr = MsgBuffer;
	Ptr+=16;
	return *(Xuint32 *)Ptr;
}

/*
* Pass it a Pointer to the start of the Ethernet Header
* Returns the Layer 2 Message Size Field
*/
Xuint32 GetSize(Xuint8 *MsgBuffer)
{
	Xuint8 * Ptr = MsgBuffer;
	Ptr+=20;
	return *(Xuint32 *)Ptr;
}


/*
* Pass it a pointer to the EMAC Address
* Fills the global variable 'array' with 
* the ETHERNET Address in standard format
*/
void fill_array(Xuint8 *Ptr)    								
{
	Xuint8 mycounter;
	for(mycounter = 0 ; mycounter < 17 ; mycounter += 3)
	{
		array[mycounter+1] = map(*(Ptr) & 0xF);
		array[mycounter] = map( ( *(Ptr) & 0xF0 ) >> 4);
		Ptr++;
		if(mycounter<15) array[mycounter+2] = '-';
	}
}


/*
* Pass it a pointer to the Ethernet Frame
* 
* Prints the Layer 2 Variables
*
* Message Header Format: 	Type			 _ 2 bytes 
*							Sequence Number	 _ 4 bytes
*                           Message Length	 _ 4 bytes
*/
void Print_Message_Fields(Xuint8 *MsgBuffer, int MsgLen, Xuint8 Extra)  	
{
	Xuint32 mycounter;
	Xuint32 LenField;
	Xuint16 TypeofMess;
	Xuint32 FragmentPayloadLength; // since FragmentLength can be different 
							// than Message PayloadLength
	Xuint8 *MesgPtr = MsgBuffer;
	Xuint8 *TemporaryPtr = (Xuint8 *)TemporaryBuffer;
		
	if(Extra == 1)
	{
		xil_printf("Message Parameters\r\n");
		xil_printf("__________________\r\n");
	}

	MesgPtr+=14;						
	TypeofMess = *(Xuint16 *)MesgPtr;
	xil_printf("Message Type Field		: %d\n\r", TypeofMess);	

	MesgPtr+=2;
	if(Extra == 1)
	{
		xil_printf("Message Sequence Nb Field	: %d\n\r", *(Xuint32 *)MesgPtr);
	}
	
	MesgPtr+=4;

	LenField = *(Xuint32 *)MesgPtr;
	
	xil_printf("Message Length			: %d\n\r", LenField);  
	
	MesgPtr+=4;

	if(LenField <= 1490)
		FragmentPayloadLength = LenField;   	// The Frame contains the Message header (10 bytes)
												// and the whole message itself as its payload	
		   // case of fragmented message
		else
		{
			if(TypeofMess == FIRST_FRAGMENT_TYPE || TypeofMess == INTERNAL_FRAGMENT_TYPE) // frame is full
				FragmentPayloadLength = MAX_L2_PAYLOAD;  
			else if (TypeofMess == LAST_FRAGMENT_TYPE) // last fragment of a message
			{
				if(LenField % MAX_L2_PAYLOAD == 0) // 1490 payload size of last fragment
					FragmentPayloadLength = MAX_L2_PAYLOAD;  
				else	
					FragmentPayloadLength = (LenField % MAX_L2_PAYLOAD);
			}	
		}

		if(Extra == 1)
		{		
			// Printing the first byte of the fragment payload
				xil_printf("Fragment Payload 1st byte: %x\n\r", *(Xuint8 *)MesgPtr);

			// Getting to the last byte of the payload	
				MesgPtr += (FragmentPayloadLength - 1);

			// Printing the last byte of the fragment payload
				xil_printf("Fragment Payload last byte: %x\n\r", *(Xuint8 *)MesgPtr);

			/*  
				xil_printf("Frame Payload			:\r\n"); 	
				for(mycounter=0 ; mycounter < FragmentPayloadLength ; mycounter++) 
				{	
					xil_printf("%x", *(Xuint8 *)MesgPtr);
					MesgPtr++; 					
				}

			*/
		}

		if(TypeofMess == 1)		// ack
			xil_printf("\r\n___________________________________________________\r\n");				
}

/*
* Pass it a pointer to the Ethernet frame 
*
* and the MsgLen as returned by the Receive function
*
* Ethernet Header Format: 	Destination Address _ 6 bytes 
*							Source Address      _ 6 bytes
*                           Len / Type Field    _ 2 bytes
*
*/
void Print_Frame_Fields(Xuint8 *MsgBuffer, int MsgLen, Xuint8 Extra)  	
{
	Xuint8 *MesgPtr = MsgBuffer;
		
	if(Extra == 1)
	{
	xil_printf("Frame Parameters\r\n");
	xil_printf("________________\r\n");
	
	xil_printf("Frame Length 			: %d\r\n", MsgLen);
	}
	
	fill_array(MesgPtr);		
	xil_printf("Destination MAC			: %s\r\n", array); 
	
	MesgPtr+=6;					
	
	fill_array(MesgPtr);			
	xil_printf("Source      MAC			: %s\r\n", array);
	
	if(Extra == 1)
	{
		MesgPtr+=6;															
		xil_printf("Payload Length			: %d\r\n", *(Xuint16 *)MesgPtr);
	}
}

