/******************************************************************************
*
*	Simple Network Sniffer __ Global Variables 
*
*	NOTE:	The local MAC Address of the sniffer is AA-AA-AA-AA-AA-AA 
*			(randomly chosen)
*			This MAC Address is reserved and should not be used for another 
*			Node on the network.
*	
* 	Author: 	Patrick E. Akl  
*           	American University of Beirut
*				August 2004
*			 	
*	For any comments, suggestions or bug discovery, please contact me at the following
*	email address : patrickakl@hotmail.com
*					
*	or contact Christopher-John Comis (University of Toronto)
*   at the following email address:
*					comis@eecg.toronto.edu
*
*******************************************************************************/



#ifndef SNIFFER_GLOBALVARIABLES_H
#define SNIFFER_GLOBALVARIABLES_H

/***************************** Constants Definitions ************************************/

#define XEM_MAX_FRAME_SIZE_IN_WORDS ((XEM_MAX_FRAME_SIZE / sizeof(Xuint32)) + 1)

#define TEST_1_OPTIONS		 (XEM_UNICAST_OPTION | XEM_INSERT_PAD_OPTION | \
                              XEM_INSERT_FCS_OPTION | XEM_INSERT_ADDR_OPTION | \
                              XEM_OVWRT_ADDR_OPTION | XEM_PROMISC_OPTION)       

#define LED    0x1					// bit 0 of GPIO is connected to the LED 
 
#define INTC_INPUT_EMAC		0		// EMAC has higher priority (check add/edit cores)

#define INTC_DEVICE_ID		0


#define ACK_L2_PAYLOAD_SIZE		36
#define ACK_L1_PAYLOAD_SIZE		46
#define ACK_FRAME_SIZE			60
#define L2_HEADER_SIZE			10
   
#define ACK_MESSAGE_TYPE			1
#define NON_FRAGMENTED_MESSAGE_TYPE	0
#define FIRST_FRAGMENT_TYPE			2
#define INTERNAL_FRAGMENT_TYPE		3
#define LAST_FRAGMENT_TYPE			4
#define MAX_L2_PAYLOAD				1490


/**************************  Instance Definitions    ************************************/ 

static XGpio Gpio;             		
static XEmac Emac;					
static XIntc InterruptController; 	  

XEmac *EmacPtr;						// Initialized in Init.h		

/**************************  MAC Addresses Definitions    *******************************/ 

static Xuint8 SnifferAddress[XEM_MAC_ADDR_SIZE] =	//   48 bits Sniffer address  
{
    0xAA, 0xAA, 0xAA, 0xAA, 0xAA, 0xAA
};

Xuint8 * LocalAddress = SnifferAddress;

/**************************  Buffer Variables    ******************************/   

static Xuint32 RecvBuffer[XEM_MAX_FRAME_SIZE_IN_WORDS];		// holds incoming data
static Xuint32 FrameLen;
static Xuint32 TemporaryBuffer;

static Xuint8 DegreeofInformation;	// this will be set by the Gpio DIP Switch to select whether to get full info 
									// or just type of frame and source and destination
static Xuint32 debouncing;

/**************************  Global Variables    ******************************/ 

char array[17];					// used to hold MAC addresses in printable standard format

/************************** Acknowledgement Variables ***********************/

XEmac_Stats Stats;  // One Variable for the EMAC Module.
			
#endif 