/******************************************************************************
*
*	Simple Network Sniffer __ Handler Functions 
*
* 	Author: 	Patrick E. Akl  
*           	American University of Beirut
*				August 2004
*			 	
*	For any comments, suggestions or bug discovery, please contact me at the following
*	email address : patrickakl@hotmail.com
*					
*	or contact Christopher-John Comis (University of Toronto)
*   at the following email address:
*					comis@eecg.toronto.edu
*
*******************************************************************************/


#include "Sniffer_GlobalVariables.h" 
#include "Sniffer_DebugFunctions.h"

/*
*	This function will read all frames on the network and will 
*	display the main parameters of the messages
*
*	We also check the state of the Gpio to check whether to print
*	some information or all the fields
*/
static void FifoRecvHandler(void *CallBackRef)		
{
	XStatus Result;
	
	if(XGpio_DiscreteRead(&Gpio) >= 2)		// no need for debouncing
    	{												
				DegreeofInformation = 1;        
		}        
	else if (XGpio_DiscreteRead(&Gpio) < 2)	// no need for debouncing    
	 	{
				DegreeofInformation = 0;				
		}	    	


	XIntc_Disable(&InterruptController, INTC_INPUT_EMAC);

	FrameLen = XEM_MAX_FRAME_SIZE;	
	Result = XEmac_FifoRecv((XEmac *)CallBackRef, RecvBuffer, &FrameLen); 
	
	if (Result != XST_SUCCESS)
	{
		xil_printf("Fifo Receive Error\n\r");
		
		XIntc_Enable(&InterruptController, INTC_INPUT_EMAC);
		return;								
	}
	else	// Success In Reception								
	{					
			xil_printf("\n\r");
			Print_Frame_Fields(RecvBuffer, FrameLen, DegreeofInformation); 
			Print_Message_Fields(RecvBuffer, FrameLen - 18, DegreeofInformation); 
	}
	
	XIntc_Enable(&InterruptController, INTC_INPUT_EMAC);
}


/*
* Checks for errors.
*/
static void FifoSendHandler(void *CallBackRef)				
{
    XEmac_GetStats((XEmac *)CallBackRef, &Stats);
    
	if (Stats.XmitLateCollisionErrors || Stats.XmitExcessDeferral)
    {
		xil_printf("Late Collision Number : %d\n\r", Stats.XmitLateCollisionErrors);
		xil_printf("Late Deferrals Number : %d\n\r", Stats.XmitExcessDeferral);
		xil_printf("Error in FIFO Sending !!\n\r");	
    }

	XEmac_ClearStats((XEmac *)CallBackRef);
}


/*
* Called in case of Errors to reset the system
*/ 
static void ErrorHandler(void *CallBackRef, XStatus Code)	
{
	xil_printf("Starting FIFO Error Handler\n\r");
    if (Code == XST_RESET_ERROR)
    {
        XEmac_Reset((XEmac *)CallBackRef);									// Reset EMAC

        (void)XEmac_SetMacAddress((XEmac *)CallBackRef, LocalAddress);		// SET MAC ADDRESS
        (void)XEmac_SetOptions((XEmac *)CallBackRef, TEST_1_OPTIONS);		// SET OPTIONS

        (void)XEmac_Start((XEmac *)CallBackRef);							// Start EMAC
    }
	xil_printf("Exiting FIFO Error Handler\n\r");
}


