/******************************************************************************
*
*	Simple Network Sniffer __ Initialization Functions 
*
*	These functions will initialize the GPio, the EMAC Controller, as well as the 
*	Interrupt Controller
*
*	In Main only Initialize_Parameters() is called. it turns the led in case everything
*	Was properly initialized and returns XST_SUCCESS
*
* 	Author: 	Patrick E. Akl  
*           	American University of Beirut
*				August 2004
*			 	
*	For any comments, suggestions or bug discovery, please contact me at the following
*	email address : patrickakl@hotmail.com
*					
*	or contact Christopher-John Comis (University of Toronto)
*   at the following email address:
*					comis@eecg.toronto.edu
*
*******************************************************************************/

#ifndef SNIFFER_INITIALIZATIONS_H
#define SNIFFER_INITIALIZATIONS_H

#include "Sniffer_GlobalVariables.h" 
#include "Sniffer_Handlers.h"

/*
* Initializes the GPio
*	DIP Switch is used to select the amount of information to sniff	
*	Led is an output
*/
static XStatus Initialize_GPio();								


/*
* Setup Interrupt System
* EMAC has input 0 of the interrupt controller
*/

static XStatus SetupInterruptSystem(XEmac *EmacPtr);

/*
* Initialize the EMAC Module
* It is configured in promiscuous mode 
* for network monitoring
*/
static XStatus InitializeEmac();

/*
* This function should be called from main
* It calls all the other functions.
*/
void Initialize_Parameters();

#endif