/******************************************************************************
*
* 	2 player Network Poker using Xilinx Multimedia Boards
* 	Authors:	Lyndon Carvalho and Hin Chan
*			ECE532 - Digital Hardware 2004/2005
*			Prof. Paul Chow
*			University of Toronto
* 
* 	Description: 	Server for a 2 player network poker game between 2
*			Xilinx Multimedia Boards connected thru a hub via
*			the ethernet
*
*******************************************************************************/
               
#ifndef SINGLEMB_INITIALIZATIONFUNCTIONS_H
#define SINGLEMB_INITIALIZATIONFUNCTIONS_H


#include "SingleMB_GlobalVariables.h" 
#include "SingleMB_HandlerFunctions.h"

/*
* Initializes the GPio
* Led is an output
*/
static XStatus Initialize_GPio();


/*
* Initializes the ACK Frame common fields 
* so that we don't do it every time we send an ACK
* at run time. 
*
* This is to reduce the computational overhead 
* The Ack Frame is contained in the Buffer ACKBuffer[60]
*
* ACK Format:
*
*   DST ADDRESS_SRC ADDRESS_ETHERNET LEN/TYPE FIELD_MESSAGE TYPE_SEQUENCE NUMBERS_MESSAGE LEN_PAYLOAD
*    unknown     automatic           known				known		unknown			known	   known        
*/
static void InitializeACKFrameCommonFields();

/*
* Setup Interrupt System
*
* EMAC has highest priority			0
* TIMER COUNTER has lowest priority 1
*/
static XStatus SetupInterruptSystem(XEmac *EmacPtr);

/*
* Initialize the Timer Counter
*/
static XStatus InitializeTimerCounter();

/*
* Initialize the EMAC Module
*/
static XStatus InitializeEmac();

/*
* This function is called from Initialize Parameters (which is the only one called from main)
* and hence there is no need to
* call it from main.
* 
* It initializes the Communication Parameters Structure contents 
*
* It assumes we have 5 boards (check the NUMBER_OF_BOARDS variable in Global Variables)
*/
void Initialize_CommVars();

/*
* This function should be called from main
* It calls all the other functions.
*/
void Initialize_Parameters();

#endif
