/******************************************************************************
*
* 	2 player Network Poker using Xilinx Multimedia Boards
* 	Authors:	Lyndon Carvalho and Hin Chan
*			ECE532 - Digital Hardware 2004/2005
*			Prof. Paul Chow
*			University of Toronto
* 
* 	Description: 	Server for a 2 player network poker game between 2
*			Xilinx Multimedia Boards connected thru a hub via
*			the ethernet
*
*******************************************************************************/

#include "xparameters.h"
#include "xbasic_types.h"
#include "xio.h"

//#include "display.h"

#define WriteReg(BaseAddress, RegOffset, Data) \
 	XIo_Out8((BaseAddress) + (RegOffset), (Xuint8)(Data))

/**************************************************************************
 * drawBigChar()
 * Draws any 2x2 characters onto the screen
 * ************************************************************************/
void drawBigChar(int start, Xuint16 color, int row, int column) {
	WriteReg(XPAR_CHAR_CTRL_BASEADDR,row*100+column,start);
	WriteReg(XPAR_COLOR_CTRL_BASEADDR,row*100+column,color);
	WriteReg(XPAR_CHAR_CTRL_BASEADDR,row*100+column+1,start+1);
	WriteReg(XPAR_COLOR_CTRL_BASEADDR,row*100+column+1,color);
	WriteReg(XPAR_CHAR_CTRL_BASEADDR,(row+1)*100+column,start+2);
	WriteReg(XPAR_COLOR_CTRL_BASEADDR,(row+1)*100+column,color);
	WriteReg(XPAR_CHAR_CTRL_BASEADDR,(row+1)*100+column+1,start+3);
	WriteReg(XPAR_COLOR_CTRL_BASEADDR,(row+1)*100+column+1,color);
}

/**********************************************************************
 * drawChar()
 * Draw a one character sized character on screen
 * ********************************************************************/
void drawChar(int start, Xuint16 color, int row, int column) {
	WriteReg(XPAR_CHAR_CTRL_BASEADDR,row*100+column,start);
	WriteReg(XPAR_COLOR_CTRL_BASEADDR,row*100+column,color);
}

/****************************************************************
 * drawCard()
 * Draw a card with value val, of suit, at specified row and 
 * column
 * *************************************************************/
void drawCard(int val, int suit, int row, int column) {
	int valaddr, color, suitaddr,i,j;

	if (val == 0) {		//turned over card
		for (i=1;i<7;i++) {
			drawChar(BLINE, BLACK, row, column+i);
			drawChar(TLINE, BLACK, row+9, column+i);
			for (j=1;j<9;j++) {
				drawChar(SOLID, CYAN, row+j, column+i);
			}	
		}
		for (i=1;i<9;i++) {
			drawChar(RLINE, BLACK, row+i, column);
			drawChar(LLINE, BLACK, row+i, column+7);
		}
		return;
	}

	switch(val) {
	case 0:		
	case 1:		valaddr = AAddr; break;
	case 2:		valaddr = KAddr; break;
	case 3:		valaddr = QAddr; break;
	case 4:		valaddr = JAddr; break;
	case 5:		valaddr = TENAddr; break;
	case 6:		valaddr = NINEAddr; break;
	case 7:		valaddr = EIGHTAddr; break;
	case 8:		valaddr = SEVENAddr; break;
	case 9:		valaddr = SIXAddr; break;
	case 10:	valaddr = FIVEAddr; break;
	case 11:	valaddr = FOURAddr; break;
	case 12:	valaddr = THREEAddr; break;
	case 13:	valaddr = TWOAddr; break;
	}

	switch(suit) {
	case 1:		suitaddr = CLUB; color = BLACK; break;
	case 2:		suitaddr = DIAMOND; color = RED; break;
	case 3:		suitaddr = HEART; color = RED; break;
	case 4:		suitaddr = SPADE; color = BLACK; break;
	}

	for (i=1;i<7;i++) {
		drawChar(BLINE, BLACK, row, column+i);
		drawChar(TLINE, BLACK, row+9, column+i);
		for (j=1;j<9;j++) {
			drawChar(SOLID, WHITE, row+j, column+i);
		}	
	}
	for (i=1;i<9;i++) {
		drawChar(RLINE, BLACK, row+i, column);
		drawChar(LLINE, BLACK, row+i, column+7);
	}
	drawBigChar(valaddr,color,row+2,column+2);
	drawBigChar(suitaddr,color,row+2,column+4);
}

/*************************************************************
 * drawBlankScreen()
 * Blank the screen from top left to bottom right
 * **********************************************************/
void drawBlankScreen() {
	int i,j;
	for (i=0; i<HEIGHT; i++) {
		for (j=0; j<WIDTH; j++) {
			drawChar(BLANK, WHITE, i, j);
		}
	}
}

/**************************************************************
 * drawChipStack()
 * Draw stack of chips for 1s, 5s, 10s stacks
 * ***********************************************************/
void drawChipStack(int value, int number, int row, int column) {
	int i,valueAddr,color,j;
	switch(value) {
	case 10:	valueAddr = TENAddr; color = BLUE; break;
	case 5:		valueAddr = FIVEAddr; color = RED; break;
	case 1:		valueAddr = ONEAddr; color = WHITE; break;
	}

	for (j=0;j<number;j++) {
		if (j==0) {
			drawChar(CIRCLE+8,  color, row,column);
			drawChar(STACK+2,   color, row,column+1);
			drawChar(STACK+3,   color, row,column+2);
			drawChar(CIRCLE+11, color, row,column+3); 
		} else {
			drawChar(STACK,   color, row-j,column);
			drawChar(STACK+2, color, row-j,column+1);
			drawChar(STACK+3, color, row-j,column+2);
			drawChar(STACK+1, color, row-j,column+3); 
		}
	}
	drawChar(CIRCLE+9,  color, row-number+1, column+1);
	drawChar(CIRCLE+10, color, row-number+1, column+2);

	drawChar(CIRCLE+4, color, row-number-1, column);
	drawChar(CIRCLE+5, color, row-number-1, column+3);
	drawChar(CIRCLE+6, color, row-number,   column);
	drawChar(CIRCLE+7, color, row-number,   column+3);
	for(i=0;i<4;i++) {
		drawChar(CIRCLE+i, color, row-number-2, column+i);
	}
	drawBigChar(valueAddr, color, row-number-1, column+1);
}

/*********************************************************
 * drawStacks()
 * Draw the all 3 stacks of 1s, 5s, 10s based on cash
 * Randomly distribute chips between each stack
 * ******************************************************/
void drawStacks(int cash, int row, int col) {
	int one, five, ten, remainder;

	//some random initial stack division
	one = cash/25;
	five = (cash/4)/5;
	ten = 71*(cash/100)/10;

	remainder = cash - (one + five*5 + ten*10);

	while (remainder>0) {
		if(remainder>=10) {
			ten++;
			remainder-=10;
		} else if (remainder >=5) {
			five++;
			remainder-=5;
		} else {
			one++;
			remainder--;
		}
	}
	if (one != 0) {
		drawChipStack(1, one, row, col);
	}
	if (five != 0) {
		drawChipStack(5, five, row, col+5);
	}
	if (ten != 0) {
		drawChipStack(10, ten, row, col+10);
	}
}

/******************************************************************
 * drawText()
 * Draw capital letters and numbers for on screen text 
 * and card values
 * ***************************************************************/
void drawText(char *text, Xuint16 color, int row, int col) { //only CAPITAL letters, and numbers
	int temp,i;
	i=0;
	while (*text != '\n') {
		temp = *text++;
		if (temp>='A' && temp <= 'Z') {
			drawBigChar( AAddr + (temp-'A')*4, color, row, col+i);
		}  else if (temp >= '0' && temp <= '9') {
			drawBigChar( ZEROAddr + (temp-'0')*4, color, row, col+i);
		} else {
			drawChar(BLANK, color, row, col+i);
			drawChar(BLANK, color, row, col+i+1);
			drawChar(BLANK, color, row+1, col+i);
			drawChar(BLANK, color, row+1, col+i+1);
		}
		i+=2;
	}
}

/***************************************************************
 * drawInt()
 * Draw integer number, with colour at row/col location
 * ************************************************************/
void drawInt(int number, Xuint16 color, int row, int col) {
	int digits, temp, base, i;

	if(number == 0) {
		drawBigChar(ZEROAddr, color, row, col);
		return;
	}


	temp = number;
	digits = 0;
	base = 10;
	while (temp != 0) {
		temp = temp - temp%base;
		base = base*10;
		digits++;
	};
	base = base/100;
	for (i=0;i<digits;i++) {
		drawBigChar(ZEROAddr + (number/base)*4, color, row, col+2*i);
		number = number - (number/base)*base;
		base = base/10;
	}
}
	
/***************************************************
 * main()
 * Main to test drawing functions
 * ************************************************/
/*
int main(void)
{
	int start = 0;
	int counter,column,color;

	color=1;
	drawBigChar(start,color++,0,0);
	start +=4;
	drawBigChar(start,color++,0,2);
	start +=4;
	drawBigChar(start,color++,0,4);
	start +=4;
	drawBigChar(start,color++,0,6);
	start +=4;
	for (counter = 0; counter<50;counter++) {
		drawBigChar(start,color++,2,column);	
		start +=4;
		column +=2;
	}
	drawCard(1,1,3*HEIGHT/4,WIDTH/2 - 8);
	drawCard(1,2,3*HEIGHT/4,WIDTH/2);
	drawChipStack(10,6, 3*HEIGHT/4+8, WIDTH/4);	
	drawChipStack(5,2, 3*HEIGHT/4+8, WIDTH/4+5);	
	drawChipStack(1,5, 3*HEIGHT/4+8, WIDTH/4+10);	

	drawCard(1,1,HEIGHT/2-7,WIDTH/2-20);
	drawCard(6,2,HEIGHT/2-7,WIDTH/2-12);
	drawCard(7,4,HEIGHT/2-7,WIDTH/2-4);
	drawCard(10,2,HEIGHT/2-7,WIDTH/2+4);
	drawCard(13,3,HEIGHT/2-7,WIDTH/2+12);

	drawCard(0,1,HEIGHT/4-14,WIDTH/2 - 8);
	drawCard(0,2,HEIGHT/4-14,WIDTH/2);
	drawChipStack(1,3, HEIGHT/4-6, WIDTH/4*3-12);	
	drawChipStack(5,5, HEIGHT/4-6, WIDTH/4*3-7);	
	drawChipStack(10,2, HEIGHT/4-6, WIDTH/4*3-2);	

	drawChipStack(5, 3, 3*HEIGHT/4 - 2, WIDTH/2-7);
	drawChipStack(1, 5, HEIGHT/4+5, WIDTH/2-5);

	drawText("ABCDEFGHIJKLMNOPQRSTUVWXYZ\n", WHITE, 15, 0);
	drawText("0123456789\n", WHITE, 17, 0);
	drawText("abc\n", WHITE, 21, 0);
	drawText("A\n", WHITE, 23, 0);

	drawInt(1, WHITE, 25, 0);
	drawInt(123, WHITE, 27, 0);
	drawInt(12345, WHITE, 29, 0);
	drawInt(145000, WHITE, 31, 0);
	drawInt(12345890, WHITE, 33, 0);

	return 0;

}
*/
