/******************************************************************************
*
* 	2 player Network Poker using Xilinx Multimedia Boards
* 	Authors:	Lyndon Carvalho and Hin Chan
*			ECE532 - Digital Hardware 2004/2005
*			Prof. Paul Chow
*			University of Toronto
* 
* 	Description: 	Server for a 2 player network poker game between 2
*			Xilinx Multimedia Boards connected thru a hub via
*			the ethernet
*
******************************************************************************/

//*************************************************
//  getCombos.c
//    These functions classify each players
//    made hand at river. Where getSF() codes 
//    flushes, straights and straight-flushes, 
//    bestCombo7() finds quads, full houses, 
//    trips, 2 pairs, pairs and simple high 
//    card hands.
//      output:  hand7[] rank7[] rank7a[]
//=================================================
#include "hands.h"

//**************************************************
//  bestCombo7()
//    This function scans the collection of
//    values in a 7-card hand and classifies
//    it as to type of poker hand. 
//==================================================
int bestCombo7(int p,int vals[14]) {
int j,n1,n2,n3,n4;
unsigned int hihand,bit;
unsigned int thand4;
unsigned int thand3,thand3a,thand3x;
unsigned int thand2,thand2a,thand2b;
unsigned int thand1,thand1a;
   bit=0x2000;  hihand=0;
   rank7[p]=rank7a[p]=0;
   //  vals[] are indexed with A=1, K=2 ... etc
   //  so scanning from 1 to 13 moves from highest
   //  ranking card value down to lowest
   n1=n2=n3=n4=0;
   bit=0x2000;  thand4=0;
   thand3=thand3a=thand3x=0;
   thand1=thand1a=thand2=thand2a=thand2b=0;
   for(j=1;j<=13;j++) {
     if(vals[j]==4) {thand4=bit; n4+=1;}
     if(vals[j]==3) {n3+=1; 
       if(n3==1) thand3=bit;
       if(n3==2) thand3a=bit;
       }
     if(vals[j]==2) {n2+=1; 
       if(n2==1) thand3a=bit; 
       if(n2==1) thand2a=bit;
       if(n2==2) thand2a=thand2a|bit;
       if(n2==3 && thand2b==0) thand2b=bit;
       }
     if(vals[j]==1) {n1+=1; 
       if(n1<=5) thand1=thand1|bit; 
       if(n1<=2) thand3x=thand3x|bit;
       if(n1<=3) thand1a=thand1a|bit;
       if(n1==1 && thand2b==0) thand2b=bit;
       }
     bit=bit>>1;
     }
   //  Quads ------------------------- rank7, rank7a
   if(n4>0) { 
     rank7[p]=thand4;  bit=0x2000;
     //  code highest valued kicker, which could 
     //  be anything from 1 card to trips
     for(j=1;j<=13;j++) {
       if(vals[j]>0 && vals[j]<4) {
         rank7a[p]=bit;  return (Quads);  }
       bit=bit>>1;  }  // for
     } // if n4>0
   //  Full House -----------------------------
   if( n3>1 || (n3==1 && n2>0) ) {
     rank7[p]=thand3;  rank7a[p]=thand3a;
     return(FHouse);  }  // if
   //-- Flush, Straight -----------------------
   if(hand7[p]==Flush) return (Flush);
   if(hand7[p]==Straight) return (Straight);
   //  Trips ----------------------------------
   if( n3==1 ) {
     rank7[p]=thand3;  rank7a[p]=thand3x;
     return(Trips);  }
   //  Two Pair -------------------------------
   if( n2>1 ) {
     rank7[p]=thand2a;  rank7a[p]=thand2b;
     return(TwoPair);  }
   //  One Pair -------------------------------
   if( n2==1 ) {
     rank7[p]=thand2a;  rank7a[p]=thand1a;
     return(Pair);  }
   //  High Card Hand -------------------------
   if( n1>=5 ) {
     rank7[p]=thand1;  return(HighCard);  }
  return 0;
}
//*****************************************************
//  getCombos()
//    This function controls the classification
//    of each players hand by type. It first
//    invokes getSF7() to search for straights,
//    flushes and straight flushes. Then it scans
//    hand values to find the remaining types.
//======================================================    
void getCombos() {
int p,k,n1,n2,test;
int vals[14];
  //  First, get the straights, flushes 
  //  and straight flushes
  getSF7();
  //  Then look for value combos
    p=0;
  nextp:
    if(hand7[p]==SFlush) goto nextpo;
    n1=p*2; n2=n1+1;
    for(k=0;k<14;k++) vals[k]=0;
    vals[valHands[n1]]+=1;
    vals[valHands[n2]]+=1;
    vals[valHands[numplayers*2]]+=1;
    vals[valHands[numplayers*2+1]]+=1;
    vals[valHands[numplayers*2+2]]+=1;
    vals[valHands[numplayers*2+3]]+=1;
    vals[valHands[numplayers*2+4]]+=1;
    //  if the value hand is higher than any
    //  previous classification, use it
    test=bestCombo7(p,vals);
    if(test>hand7[p]) hand7[p]=test;
  nextpo:  
    p+=1;
    if(p<numplayers) goto nextp;
}
