/******************************************************************************
*
* 	2 player Network Poker using Xilinx Multimedia Boards
* 	Authors:	Lyndon Carvalho and Hin Chan
*			ECE532 - Digital Hardware 2004/2005
*			Prof. Paul Chow
*			University of Toronto
* 
* 	Description: 	Server for a 2 player network poker game between 2
*			Xilinx Multimedia Boards connected thru a hub via
*			the ethernet
*
*******************************************************************************/

//***************************************************
//   getSF7.c
//     This file contains the part of a
//     poker hand evaluator that resolves
//     straights, flushes and straight flushes.
//     Unclassified hands are set to zero.
//===================================================
#include <stdio.h>
#include <stdlib.h>
#include "hands.h"

//================================================
//  stripBITS()
//    This function strips off the low 6th
//    or 7th card values from the bit
//    coded hand.
//------------------------------------------------ 
unsigned int stripBITS(unsigned int thand) {
unsigned int imask,xhand;
int j,n1;
  imask=0x2000;  n1=0;  xhand=thand;
  for(j=1;j<=13;j++) {
    if(imask & xhand) {
      n1+=1; if(n1>5) xhand=(xhand ^imask);  }
    imask=imask>>1;
    }
  return (xhand);
}
//================================================
//  loadFBITS7()
//    This function scans a 7 card hand and
//    pulls out those cards that belong to
//    the longest suit. It should be called
//    only after a flush count has been found.
//------------------------------------------------
unsigned int loadFBITS7(int vth) {
int n1,n2,thand;
  n1=vth*2;  n2=n1+1;  
  nf=0;  thand=0; 
  if(suitHands[n1]==longsuit7[vth]){
    thand|=(bitHands[n1]&0x3fff);  nf+=1;}
  if(suitHands[n2]==longsuit7[vth]){
    thand|=(bitHands[n2]&0x3fff);  nf+=1;}
  if(suitHands[numplayers*2]==longsuit7[vth]){
    thand|=(bitHands[24]&0x3fff);  nf+=1;}
  if(suitHands[numplayers*2+1]==longsuit7[vth]){
    thand|=(bitHands[25]&0x3fff);  nf+=1;}
  if(suitHands[numplayers*2+2]==longsuit7[vth]){
    thand|=(bitHands[26]&0x3fff);  nf+=1;}
  if(suitHands[numplayers*2+3]==longsuit7[vth]){
    thand|=(bitHands[27]&0x3fff);  nf+=1;}
  if(suitHands[numplayers*2+4]==longsuit7[vth]) {
    thand|=(bitHands[28]&0x3fff);  nf+=1;}
  return (thand);
}
//===============================================
//  resolveSF7()
//    This function is called when both a
//    straight and a flush have been found
//    in a players hand. Its job is to resolve
//    whehter the hand should be coded as a
//    Flush or as a Straight Flush.
//----------------------------------------------
int resolveSF7(int p) {
  int s,thand;
  //  form a hand containing only the long suit
  //  then see if it's still a completed straight
  thand=loadFBITS7(p);
  s=table7[thand];
  if(s>=1 && s<=10) {
    //  This is a STRAIGHT FLUSH. It could be more
    //  than 5 cards long, but our look-up table
    //  takes care of that by returning only the
    //  high straight code (1-10). (We do need to
    //  make the highest value the highest rank).
    rank7[p]=(11-s); return (SFlush); }
    //  This is a FLUSH. It could be more than 5
    //  cards long, so we need to strip off any
    //  extra low card values
  if(nf>5) thand=stripBITS(thand);
  rank7[p]=thand; 
  return (Flush);
}
//===================================================
//  resolveF7()
//    A flush hand may contain 5, 6 or 7 cards
//    in the long suit. This function strips off
//    any extra lower-ranking cards so that the
//    rank of the hand is the value of the highest
//    5 cards.
//-------------------------------------------------- 
int resolveF7(int n) {
unsigned int thand;
  //  First, we need to bit code all the cards
  //  in the hand that share the long suit
  thand=loadFBITS7(n);
  //  Then, if there are more than 5 cards in the
  //  long suit we need to strip off the lowest
  //  valued ones in excess of 5.
  if(nf>5) thand=stripBITS(thand);
  rank7[n]=thand;
  return (Flush);
}
//===================================================
//  resolveS7()
//    Returns an adjusted code for a completed
//    straight. The table values 1-10 are revised
//    so that the highest ranking straight (AKQJT)
//    is given the highest numeric value (1).
//---------------------------------------------------
int resolveS7(int n) {
  rank7[n]=(11-hands7[n]);
  return (Straight);
}
//****************************************************
//  getSF7()
//    Start overall hand evaluation by looking
//    for straights, flushes and straight flushes.
//    hand7[] and rank7[] are filled in when
//    one of these hands is found.
//====================================================
void getSF7() {
int p,sflag,fflag;
    p=0;
  again:
    hand7[p]=0; rank7[p]=0; 
    sflag=0; fflag=0;
    if(hands7[p]>=1&&hands7[p]<=10) sflag=1;
    if(handf7[p]>=5) fflag=1;
    //  Code hands that contain BOTH a flush
    //  and a Straight.
    if(fflag==1 && sflag==1) {
      hand7[p]=resolveSF7(p);
      goto repeat; }
    //  Otherwise, code Flush hands and if none
    //  code Straight hands.
    if(fflag==1) {
      hand7[p]=Flush;
      goto repeat;  }
    if(sflag==1) {
      hand7[p]=Straight;
      goto repeat; }
    repeat:
      p+=1;
      if(p<numplayers) goto again;
}
