/******************************************************************************
*
* 	2 player Network Poker using Xilinx Multimedia Boards
* 	Authors:	Lyndon Carvalho and Hin Chan
*			ECE532 - Digital Hardware 2004/2005
*			Prof. Paul Chow
*			University of Toronto
* 
* 	Description: 	Server for a 2 player network poker game between 2
*			Xilinx Multimedia Boards connected thru a hub via
*			the ethernet
*
*******************************************************************************/

//*******************************************************
//   getstr7s.c
//     Categorize 7 card hands for their
//     straightness. 
//-------------------------------------------------------

//=======================================================
//  buildtable7()
//    This function is called once to build
//    the 7 card straight and straight draw table
//      1-10  (10) Completed Straights
//-------------------------------------------------------
//     A    K     Q    J   T   9    8  7  6  5   4 3 2 A
//  8192 4096  2048 1024 512 256  128 64 32 16   8 4 2 1
void buildtable7() {
int j;
unsigned int c1,c2,c2a,c3;
  //  1.  fill table with null entries
  for(j=0;j<16384;j++) {table7[j]=0;} 
  //--------------------------------------------------
  //  2.  set up mask for 5 card completed straights
  //    1-AKQJT  2-KQJT9  3-QJT98  4-JT987  5-T9876
  //    6-98765  7-87654  8-76543  9-65432 10-5432A
  c1=0x3e01;   //  AKQJT
  for(j=1;j<=10;j++) {
    table7[c1]=j; c1=c1>>1;
    if(c1&1) c1|=0x2000;
    }
  //    since there are 7 cards, but only 5 cards
  //    accounted for so far, we need to provide now
  //    for all possible 6th and 7th card values
  //    for each of 10 completed straights
  c1=0x3e01;   // AKQJT
  for(j=1;j<=10;j++) {
      c2=0x2001;
    nextc2ab:
      c2a=0x2001;
    nextc2ac:
      c3=(c1|c2|c2a);
      if(c3&1) c3|=0x2000; 
      if(table7[c3]==0) {table7[c3]=j;}
      c2a=c2a>>1;
      if(c2a>1) goto nextc2ac;
      c2=c2>>1;
      if(c2>1) goto nextc2ab;
    c1=c1>>1;
    }
}
//***************************************************
//   getstr7s()
//     This function is called after each
//     round of holdem is dealt.
//====================================================
void getstr7s() {
int j,n1,n2;
unsigned int a1,c3;
unsigned int board;
static int iflag=0;
  if(iflag==0) {iflag=1; buildtable7();}
  board=(bitHands[numplayers*2]&0x3fff)|
        (bitHands[numplayers*2+1]&0x3fff)|
        (bitHands[numplayers*2+2]&0x3fff)|
        (bitHands[numplayers*2+3]&0x3fff)|
        (bitHands[numplayers*2+4]&0x3fff);
  for(j=0;j<numplayers;j++) {
    n1=j*2;  n2=n1+1;
    a1=(bitHands[n1]&0x3fff)|(bitHands[n2]&0x3fff);
    c3=a1|board;
    hands7[j]=table7[c3];
    }
}
