/******************************************************************************
*
* 	2 player Network Poker using Xilinx Multimedia Boards
* 	Authors:	Lyndon Carvalho and Hin Chan
*			ECE532 - Digital Hardware 2004/2005
*			Prof. Paul Chow
*			University of Toronto
* 
* 	Description: 	Server for a 2 player network poker game between 2
*			Xilinx Multimedia Boards connected thru a hub via
*			the ethernet
*
*******************************************************************************/

//*****************************************************
//  printHands.c
//    This file contains print utility functions
//=====================================================
#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include "hands.h"



void printBITS(int v) {
int j;
unsigned int bits;
  bits=0x2000;
  for(j=1;j<=13;j++) {
    if( bits & v ) {
      if( j==1)  printf("A");
      if( j==2)  printf("K");
      if( j==3)  printf("Q");
      if( j==4)  printf("J");
      if( j==5)  printf("T");
      if( j==6)  printf("9");
      if( j==7)  printf("8");
      if( j==8)  printf("7");
      if( j==9)  printf("6");
      if( j==10) printf("5");
      if( j==11) printf("4");
      if( j==12) printf("3");
      if( j==13) printf("2");
    } // if
  bits=bits>>1;
  }  // j
}
void print3X(int n) {
  if(n==1) printf(" AAA");
  if(n==2) printf(" KKK");
  if(n==3) printf(" QQQ");
  if(n==4) printf(" JJJ");
  if(n==5) printf(" TTT");
  if(n==6) printf(" 999");
  if(n==7) printf(" 888");
  if(n==8) printf(" 777");
  if(n==9) printf(" 666");
  if(n==10) printf(" 555");
  if(n==11) printf(" 444");
  if(n==12) printf(" 333");
  if(n==13) printf(" 222");
}
void print2X(int n) {
  if(n==1) printf(" AA");
  if(n==2) printf(" KK");
  if(n==3) printf(" QQ");
  if(n==4) printf(" JJ");
  if(n==5) printf(" TT");
  if(n==6) printf(" 99");
  if(n==7) printf(" 88");
  if(n==8) printf(" 77");
  if(n==9) printf(" 66");
  if(n==10) printf(" 55");
  if(n==11) printf(" 44");
  if(n==12) printf(" 33");
  if(n==13) printf(" 22");
}
void printQUADS(int n) {
  if(n==1) printf(" AAAA ");
  if(n==2) printf(" KKKK ");
  if(n==3) printf(" QQQQ ");
  if(n==4) printf(" JJJJ ");
  if(n==5) printf(" TTTT ");
  if(n==6) printf(" 9999 ");
  if(n==7) printf(" 8888 ");
  if(n==8) printf(" 7777 ");
  if(n==9) printf(" 6666 ");
  if(n==10) printf(" 5555 ");
  if(n==11) printf(" 4444 ");
  if(n==12) printf(" 3333 ");
  if(n==13) printf(" 2222 ");
}
void printSTR(int n) {
  if(n==1) printf(" AKQJT "); 
  if(n==2) printf(" KQJT9 ");
  if(n==3) printf(" QJT98 ");
  if(n==4) printf(" JT987 ");
  if(n==5) printf(" T9876 ");
  if(n==6) printf(" 98765 ");
  if(n==7) printf(" 87654 ");
  if(n==8) printf(" 76543 ");
  if(n==9) printf(" 65432 ");
  if(n==10) printf(" 5432A ");
}
void printFLUSH(int n) {
unsigned int imask;
int j;
  imask=0x2000;
  for(j=1;j<=13;j++) {
    if(imask&n) {
      if(j==1) printf("A");
      if(j==2) printf("K");
      if(j==3) printf("Q");
      if(j==4) printf("J");
      if(j==5) printf("T");
      if(j==6) printf("9");
      if(j==7) printf("8");
      if(j==8) printf("7");
      if(j==9) printf("6");
      if(j==10) printf("5");
      if(j==11) printf("4");
      if(j==12) printf("3");
      if(j==13) printf("2");
      if(j==14) printf("A");
      }  
    else printf(".");
    imask=imask>>1;  }
}
void printSuit(int s) {
  if(s==1) {printf("c"); return;}
  if(s==2) {printf("d"); return;}
  if(s==3) {printf("h"); return;}
  if(s==4) {printf("s"); return;}
  printf("**ERR");
}
void printVal(int v) {
  if(v==1) {printf("A"); return;}
  if(v==2) {printf("K"); return;}
  if(v==3) {printf("Q"); return;}
  if(v==4) {printf("J"); return;}
  if(v==5) {printf("T"); return;}
  if(v==6) {printf("9"); return;}
  if(v==7) {printf("8"); return;}
  if(v==8) {printf("7"); return;}
  if(v==9) {printf("6"); return;}
  if(v==10){printf("5"); return;}
  if(v==11){printf("4"); return;}
  if(v==12){printf("3"); return;}
  if(v==13){printf("2"); return;}
  printf("**ERR");
}
void printHand(int v) {
  switch(v) {
    case SFlush:   printf(" S Flush "); return;
    case Quads:    printf("   Quads "); return;
    case FHouse:   printf(" F House "); return;
    case Flush:    printf("   Flush "); return;
    case Straight: printf("Straight "); return;
    case Trips:    printf(" 3x Kind "); return;
    case TwoPair:  printf("  2 Pair "); return;
    case Pair:     printf("  1 Pair "); return;
    case HighCard:  case 0:
                   printf("    Bust "); return;
    default: printf("* ERR * "); return;
    }
}

//===========================================
void printPlayer(int n) {
int n1,n2;
  if(n<0 || n>11) return;
  n1=n*2;  n2=n1+1;
  printf("  ");
  printVal( valHands[n1] );
  printSuit( suitHands[n1] );
  printVal( valHands[n2] );
  printSuit( suitHands[n2] );
  printf(" ");
  printVal( valHands[numplayers*2] );
  printSuit( suitHands[numplayers*2] );
  printVal( valHands[numplayers*2+1] );
  printSuit( suitHands[numplayers*2+1] );
  printVal( valHands[numplayers*2+2] );
  printSuit( suitHands[numplayers*2+2] );
  printf(" ");
  printVal( valHands[numplayers*2+3] );
  printSuit( suitHands[numplayers*2+3] );
  printf(" ");
  printVal( valHands[numplayers*2+4] );
  printSuit( suitHands[numplayers*2+4] );
}

//*******************************************
//  printHands()
//    This function simply prints out
//    the decoded player holdem hands
//    produced in a shuffle
//-------------------------------------------
void printHands(int turn) {
int j,n1,n2,n3,numcards;
int row, column;

drawBlankScreen();
row =0; column =0;
  for(j=1;j<=numplayers;j++) {
	printf("%5d",j);
	drawText("PLAYER\n", WHITE, nameRow[(j+numplayers-playerid)%numplayers], nameCol[(j+numplayers-playerid)%numplayers]);
	drawInt(j, WHITE, nameRow[(j+numplayers-playerid)%numplayers], nameCol[(j+numplayers-playerid)%numplayers]+12);
  };
  printf("\n  "); 
  n1=0;
  do {
	  if ((n1 + 1 == playerid) || turn == 4) {
		n2=n1*2;  n3=n2+1;
		printVal( valHands[n2] );
		printSuit( suitHands[n2] );
		drawCard(valHands[n2],suitHands[n2],cardRow[(n1+numplayers-(playerid-1))%numplayers],cardCol[(n1+numplayers-(playerid-1))%numplayers]);
		printVal( valHands[n3] );
		printSuit( suitHands[n3] );
		drawCard(valHands[n3],suitHands[n3],cardRow[(n1+numplayers-(playerid-1))%numplayers],cardCol[(n1+numplayers-(playerid-1))%numplayers]+8);
	  } else {
		  printf("XXXX");
		  drawCard(0,0,cardRow[(n1+numplayers-(playerid-1))%numplayers],cardCol[(n1+numplayers-(playerid-1))%numplayers]);
		  drawCard(0,0,cardRow[(n1+numplayers-(playerid-1))%numplayers],cardCol[(n1+numplayers-(playerid-1))%numplayers]+8);
	  }
      printf(" ");
	  n1+=1;
  } while (n1<numplayers);
  printf("\n  ");
  
  n1=0;
  do {
	  printf("%d ",cash[n1]);
	  drawBigChar(DOLLARSIGN, WHITE, stackRow[n1]+2, stackCol[n1]+5);
	  drawInt(cash[n1], WHITE, stackRow[(n1+numplayers-(playerid-1))%numplayers]+2, stackCol[(n1+numplayers-(playerid-1))%numplayers]+7);
	  drawStacks(cash[n1], stackRow[(n1+numplayers-(playerid-1))%numplayers], stackCol[(n1+numplayers-(playerid-1))%numplayers]+2);
	  n1++;
  } while (n1<numplayers);
  printf("\n");

  if (turn == 0) {
		numcards = 0;
  } else {
	  if (turn != 4) {
		numcards = 2+turn;
	  } else {
		  numcards = 5;
	  }
	  printf("  Board: ");
  }

  for(j=numplayers*2;j<numplayers*2+numcards;j++) {
    printVal( valHands[j] );
    printSuit( suitHands[j] );
    printf(" ");
	drawCard(valHands[j],suitHands[j],commRow, commCol + 8*(j-numplayers*2));
    }
  printf("\n\n");

  for(j=0;j<numplayers;j++) {
	  drawStacks(bet[j],betRow[(j+numplayers-(playerid-1))%numplayers],betCol[(j+numplayers-(playerid-1))%numplayers]);
  }

  drawStacks(pot, 3*HEIGHT/4-5, 3*WIDTH/4);
  drawText("POT\n", WHITE, 3*HEIGHT/4-3, 3*WIDTH/4);
  drawBigChar(DOLLARSIGN, WHITE, 3*HEIGHT/4-3, 3*WIDTH/4+8);
  drawInt(pot, WHITE, 3*HEIGHT/4-3, 3*WIDTH/4+10);

}


