/******************************************************************************
*
* 	2 player Network Poker using Xilinx Multimedia Boards
* 	Authors:	Lyndon Carvalho and Hin Chan
*			ECE532 - Digital Hardware 2004/2005
*			Prof. Paul Chow
*			University of Toronto
* 
* 	Description: 	Server for a 2 player network poker game between 2
*			Xilinx Multimedia Boards connected thru a hub via
*			the ethernet
*
*******************************************************************************/

/****************************************************

//  sendHands()

//		Fills BigBuffer with frame for sending the 
//		dealt hand to the client board.  Sends frame
//		using FragmentandSendReliably fucntion

*****************************************************/
void sendHands() {
	Xuint8 counter;  
	Xuint8 * BigPtr;


	BigPtr = (Xuint8 *)BigBuffer;
	*(Xuint8 *) BigPtr = (Xuint8) (1); // frame type integer so client knows what kind of fram we are sending 1 = cards frame
	BigPtr++;
	for(counter = 0 ; counter < numplayers*2+5 ; counter++)
	{	
		// filling buffer with each card value and suit
		*(Xuint8 *) BigPtr = (Xuint8) (valHands[counter]);
		//xil_printf("BigPtr: %d\n", *(Xuint8 *)BigPtr);
		BigPtr ++;
		
		*(Xuint8 *) BigPtr = (Xuint8) (suitHands[counter]);  
//		xil_printf("BigPtr: %d\n", *(Xuint8 *)BigPtr);
		BigPtr ++;
	}        
	BigPtr = (Xuint8 *)BigBuffer;

	// send bigbuffer as ethernet frame of 1000 bytes to MAC Address2 (from MACAddress.h file)
	if(Fragment_and_Send_Reliably(100, BigPtr, Address2) == XST_SUCCESS)    
	{   	
		xil_printf("Send Hands Succeeded !!\n\r");	 		 
	}                
	else                            
	{          
		xil_printf("Send Hands Error !!\n\r");
	}
}


/****************************************************

//  sendCash()

//		Fills BigBuffer with frame for sending the 
//		cash of each player to the client board.

*****************************************************/
void sendCash() {
	Xuint8 counter;   
	Xuint8 * BigPtr;

	BigPtr = (Xuint8 *)BigBuffer;
	*(Xuint8 *) BigPtr = (Xuint8) (2); // frame type integer 2 to identify a cash frame
	BigPtr++;
	for(counter = 0 ; counter < numplayers ; counter++)
	{	
		*(Xuint8 *) BigPtr = (Xuint8) (cash[counter]);
//		xil_printf("BigPtr: %d\n", *(Xuint8 *)BigPtr);
		BigPtr ++;
	}
	*(Xuint8 *) BigPtr = (Xuint8) (pot);       
	BigPtr = (Xuint8 *)BigBuffer;

	if(Fragment_and_Send_Reliably(100, BigPtr, Address2) == XST_SUCCESS)    
	{   	
		xil_printf("Send Cash Succeeded !!\n\r");	 		 
	}                
	else                            
	{          
		xil_printf("Send Cash Error !!\n\r");
	}	
}

/****************************************************

//  sendTurn()

//		Fills BigBuffer with frame for sending the 
//		turn of each player to the client board.

*****************************************************/
void sendTurn(int i) {
	Xuint8 counter;
	Xuint8 * BigPtr;

	BigPtr = (Xuint8 *)BigBuffer;
	*(Xuint8 *) BigPtr = (Xuint8) (3); // frame type integer 3 for turn
	BigPtr++;
	*(Xuint8 *) BigPtr = (Xuint8) (i); // turn integer
	BigPtr = (Xuint8 *)BigBuffer;
	if(Fragment_and_Send_Reliably(100, BigPtr, Address2) == XST_SUCCESS)    
	{   	
		xil_printf("Send Turn Succeeded !!\n\r");	 		 
	}                
	else                            
	{          
		xil_printf("Send Turn Error !!\n\r");
	}
}

/****************************************************

//  sendDoBet()

//		Fills BigBuffer with frame for sending the 
//		request of a bet from the client board.

*****************************************************/
void sendDoBet() {
	Xuint8 counter;   
	Xuint8 * BigPtr;

	BigPtr = (Xuint8 *)BigBuffer;
	*(Xuint8 *) BigPtr = (Xuint8) (4); // frame type integer 4 for bet request
	BigPtr++;
	*(Xuint8 *) BigPtr = (Xuint8) (maxcurrentbet);  // maximum bet on table so client knows how much to call
	BigPtr = (Xuint8 *)BigBuffer;
	if(Fragment_and_Send_Reliably(100, BigPtr, Address2) == XST_SUCCESS)    
	{   	
		xil_printf("Send DoBet Succeeded !!\n\r");	 		 
	}                
	else                            
	{          
		xil_printf("Send DoBet Error !!\n\r");
	}
}

/****************************************************

//  sendStatus()

//		Fills BigBuffer with frame for sending the
//		status of the hand and the winners and
		winning amount 

*****************************************************/
void sendStatus(int status, int playa, int amount) {
	Xuint8 counter;   
	Xuint8 * BigPtr;

	BigPtr = (Xuint8 *)BigBuffer;
	*(Xuint8 *) BigPtr = (Xuint8) (6);
	BigPtr++;
	*(Xuint8 *) BigPtr = (Xuint8) (status);
	BigPtr++;
	*(Xuint8 *) BigPtr = (Xuint8) (playa);
	BigPtr++;
	*(Xuint8 *) BigPtr = (Xuint8) (amount);
	BigPtr = (Xuint8 *)BigBuffer;
	if(Fragment_and_Send_Reliably(100, BigPtr, Address2) == XST_SUCCESS)    
	{   	
		xil_printf("Send Status Succeeded !!\n\r");	 		 
	}                
	else                            
	{          
		xil_printf("Send Status Error !!\n\r");
	}
}


/****************************************************

//  sendConnect()

//		Fills BigBuffer with frame for sending the
//		connect frame from client to server

*****************************************************/
void sendConnect() {
       Xuint8 counter;
       Xuint8 * BigPtr;

       BigPtr = (Xuint8 *)BigBuffer;
       *(Xuint8 *) BigPtr = (Xuint8) (7);
       //BigPtr++;
       if(Fragment_and_Send_Reliably(1, BigPtr, Address1) == XST_SUCCESS)
       {
               xil_printf("Send Connect Succeeded !!\n\r");
       }
       else
       {
               xil_printf("Send Connect Error !!\n\r");
       }
}

/****************************************************

//  sendBet()

//		Fills BigBuffer with frame for sending the
//		bet amount from client to server

*****************************************************/

void sendBet(int amount) {
       Xuint8 counter;
       Xuint8 * BigPtr;

       BigPtr = (Xuint8 *)BigBuffer;
       *(Xuint8 *) BigPtr = (Xuint8) (5);
       BigPtr++;
       *(Xuint8 *) BigPtr = (Xuint8) (amount);
	   BigPtr = (Xuint8 *)BigBuffer;

       if(Fragment_and_Send_Reliably(2, BigPtr, Address1) == XST_SUCCESS)
       {
//               xil_printf("Send Bet Succeeded !!\n\r");
       }
       else
       {
               xil_printf("Send Bet Error !!\n\r");
       }
}