/******************************************************************************
*
* 	2 player Network Poker using Xilinx Multimedia Boards
* 	Authors:	Lyndon Carvalho and Hin Chan
*			ECE532 - Digital Hardware 2004/2005
*			Prof. Paul Chow
*			University of Toronto
* 
* 	Description: 	Server for a 2 player network poker game between 2
*			Xilinx Multimedia Boards connected thru a hub via
*			the ethernet
*
*******************************************************************************/
                            
/*****************************  Include Files *********************************/

#include <stdio.h>

#include <math.h>
#include <stdlib.h>


#include "xemac.h"		      	// Ethernet Module             	       
#include "xparameters.h"             			                              
#include "xstatus.h"                                                                             
                                                           
#include "mb_interface.h"       // MicroBlaze  
#include "xintc.h"       		// for interrupt control
#include "xgpio.h"    			// for the switch  
#include "xtmrctr.h"			// To implement delayed frame retransmissions 

#include "globals.h"
#include "SingleMB_MACAddresses.h"				// contains the MAC Address Definitions and some functions
#include "SingleMB_GlobalVariables.h" 			// contains the global variables shared among the 5 files
#include "SingleMB_HandlerFunctions.h" 			// contains handler functions 
#include "SingleMB_SendFunctions.h"				// contains the send functions of frame and message layers
#include "SingleMB_InitializationFunctions.h"	// contains the initialization functions
#include "SingleMB_DebuggingFunctions.h"		// contains the functions to display frame 
												// and message headers and payload...
#include "display.h"


#include "SingleMB_MACAddresses.c"				// contains the MAC Address Definitions and some functions
#include "SingleMB_HandlerFunctions.c" 			// contains handler functions 
#include "SingleMB_SendFunctions.c"				// contains the send functions of frame and message layers
#include "SingleMB_InitializationFunctions.c"	// contains the initialization functions
#include "SingleMB_DebuggingFunctions.c"		// contains the functions to display frame and message headers and payload...

#include "dealholdem.c"  	// contains the functions which shuffle up and deal random holdem hands

#include "fastran2.c"		// random number generator for generating and shuffling the hands

#include "getCombos.c"		// evaluator functions for the finding combos between player hands and board

#include "getf.c"			
#include "getSF.c"
#include "getstr7s.c"
#include "display.c"		// functions to display cards using the character mode SVGA

#include "printHands.c"		// print functions to display SVGA cards as well as text in teraterm

#include "shuffle.c"		// shuffling function used by dealHands

#include "winners.c"		// evaluates the winners
#include "betting.c"		// functions to handle betting of each player
#include "send.c"		// send frame functions



/*****************************************************

	getS()

		This function sets up the straight

    	look-up tables for 7 card

    	holdem hands.  During a run it scans each players 

    	hand and classifies it for straightness.

******************************************************/

void getS() {

  getstr7s();

}


/*****************************************************

	evaluate()

		Conrols the classification of each players

		hand by type of poker hand (flush, full 

		house, etc).
*****************************************************/

void evaluate() {

  getF();

  getS();  

  getCombos();  // codes all val combo hands

}

/****************************************************

//  fillCash()

//		Fills each players cash at beginning of game

*****************************************************/
void fillCash() {
	Xuint8 counter;   
	for(counter = 0 ; counter < numplayers ; counter++)
	{	
		cash[counter] = 100;
		//xil_printf("cash[%d] = %d\n\r", counter, cash[counter]);
	}  
}

void delay_loop() {
	int counter = 0;
	printf ("fdfsaaf\r\n");
	while (counter < 100000) {
		counter += 1;
	}
	printf ("fdfsaaf\r\n");
}


/*********************************    MAIN FUNCTION      *******************************/
int main()       
{	     
	/* Definitions */ 	
	Xuint8 * TempAddressPtr;
	Xuint8 *BigPtr;   	
	char ch;
	int i,j,k,l,nloops,start,numfolded,player,over;

	playerid = 1;
	num = numplayers;
	blind = 1;
	button = 0;


	Initialize_Parameters();	// for EMAC and TIMERCOUNTER and INTERRUPTS and GPIO
	xil_printf("\n\n");

	fillCash();  // fill each players cash at start of game

	connect = 0;
	xil_printf("Waiting for connection...\n\r");
        while (connect==0) {
	  // wait for client to interrupt with connection
	  // set SEED while waitingo for incoming connection
	  SEED +=1;
	}
	
	xil_printf("Received Connection, dealing Hand...\n\r");

	sendCash(); // send initial cash balances to client

	nloops= 10000;  // max number of playable hands
	for(j=1;j<=nloops;j++) {
		pot = 0;
		dealHoldem(); //  generates the hands
		sendHands();  // send the new cards to the client
		sendCash();   
		numfolded = 0;
		over = 0;
		for (l=0; l<num; l++) {		// new hand, reset status to betting
			if (status[l] != OUT) {
				status[l] = STILLTOBET;
			}
			totalbet[l]=0;
		}

		for (i=0; i<4; i++) {		// loop for 4 turns of betting
			sendTurn(i); // send the current status of the game (flop, turn, river)
			maxcurrentbet = 0;
			for (l=0;l<num;l++) {	// reset for after dealing more card(s)
				bet[l] = 0;
				if (status[l] <= RAISED)
					status[l]=STILLTOBET;
			}
			printHands(i);
			if (i == 0) {	// who goes first
				getBlinds();
				start = button + 3;
			} else {
				start = button + 1;
			}
			sendCash();

			do {	// do loop until everyone has either folded, called or allin
				for (k=start;k<(start+num);k++) { //looping through players
					player = k%num;

					if(status[player] == STILLTOBET) {	// player needs to bet
						printf("1bet[%d] = %d\r\n", player, bet[player]);
						playerbet = getBet(player);
						printf("playerbet = %d\r\n", playerbet);
						if (playerbet == -1) {			//player folded
							status[player] = FOLDED;
							numfolded++;
							if(numfolded == num - 1) { //has everyone else folded?
								over = 1;
								break;
							}
						} else {	// player didn't fold
							if (playerbet > cash[player]) {	// bet more than has cash, ie ALLIN
								status[player] = ALLIN;
								playerbet = cash[player];
							}							
							cash[player] -= (playerbet);
							printf("2playerbet = %d\r\n", playerbet);
							printf("2a_bet[%d] = %d\r\n", player, bet[player]);
							bet[player] += playerbet;
							printf("2b_bet[%d] = %d\r\n", player, bet[player]);
							totalbet[player] += playerbet;
							if(bet[player] > maxcurrentbet) { // raised
								for(l=0;l<num;l++) {
									if (l != player && (status[l] <= RAISED)) {
										status[l] = STILLTOBET;	//make everyone who hasn't folded bet
									}
								}
								maxcurrentbet = bet[player];
								if (cash[player] != 0) {
									status[player] = RAISED;
								}
							} else {	// called
								status[player] = CALLED;
							}
						}							
					}
					printf("3bet[%d] = %d\r\n", player, bet[player]);
					printHands(i);
					sendCash();
					xil_printf("Pot: %d\n\r", pot);
				}
				if (over) {	// for breaking out of loop when only 1 player left
					break;
				}
				called = 1;
				for (l=0;l<num;l++) {	// players left that still needs to bet/call?
					if (status[l] == STILLTOBET) {
						called =0;
					}
				}
					
			} while (!called);
			pot = 0;
			for (l=0;l<num;l++) {	// calculating pot
				pot += totalbet[l];
			}
			if (over) break;
		}
		pot = 0;
		for (l=0;l<num;l++) {	// calculating pot
			pot += totalbet[l];
		}

		if (!over) {
			printHands(4);
			xil_printf("Pot: %d\n", pot);
			sendTurn(4);
		}

		evaluate();   //  classifies each players hands for hand type (pair, 2 pairt, trips etc.)
		sendTurn(5);  // no one folded, reveal all cards
		for (l=0;l<num;l++) {	// reset each players pot for printing winner
			bet[l] = 0;
		}
		printHands(i);
		sendCash();
		do {
			maxbet = 0;
			secondmaxbet = 0;
			sidepot = 0;
			for (i=0; i<num; i++) {	//what's at stake?
				if (status[i] <= 3) {
					if (totalbet[i] > maxbet) {
						secondmaxbet = maxbet;
						maxbet = totalbet[i];
						//if (status[i] <= 3) numwithmaxbet = 1;
					} else if ((totalbet[i] > secondmaxbet) && (totalbet[i] != maxbet)) {
						secondmaxbet = totalbet[i];
					}
				}
			}

			for (i=0; i<num; i++) {
				sidepot += totalbet[i]-secondmaxbet;
			}

			winners(num);  //  finds the winner(s)  
			sidepot = 0;
			for (i=0; i<num; i++) {
				if (totalbet[i] != 0) {
					sidepot = 1;
				}
			}
		} while (sidepot);
		
		l=0;
		for (i=0; i<num; i++) {
			if (cash[i] == 0) {
				status[i] = OUT;
				l++;
			}
		}
		// player has no money left, GAME OVER exit game
		if (l == numplayers - 1) {
			printf("GAME OVER!!\r\n");
			drawText("GAME OVER\n", BLACK, HEIGHT/2, WIDTH/2-8);
			sendStatus(4, 0, 0);
			return 0;
		}
		
		do {
		button++;
		} while (status[button] == OUT);

		printf("Hit Enter to Deal Again? ");
		getchar();

	}
	return 0;
}

/*********************************************************************************************/




