/******************************************************************************
*
* 	2 player Network Poker using Xilinx Multimedia Boards
* 	Authors:	Lyndon Carvalho and Hin Chan
*			ECE532 - Digital Hardware 2004/2005
*			Prof. Paul Chow
*			University of Toronto
* 
* 	Description: 	Server for a 2 player network poker game between 2
*			Xilinx Multimedia Boards connected thru a hub via
*			the ethernet
*
*******************************************************************************/

#include <stdio.h>
#include "hands.h"


//=================================================
//  foundWins()
//    divides the pot up among the winning
//    player hands, where
//      n - number of players with winner
//      key - player qualifying key
//      high - type of winning hand
//    This is where all tabulations about
//    winning hands can be done.
//-------------------------------------------------
void foundWins(int key,int high,int n) {
int j;  
  for(j=0;j<num;j++) {
    if(player[j]==key) {
		xil_printf("Player %d wins with ", j+1);
		switch(high) {
			case SFlush:	xil_printf("straight flush\n\r"); break;
			case Flush:	xil_printf("flush\n\r"); break;
			case Straight:	xil_printf("straight\n\r"); break;
			case HighCard:	xil_printf("high card\n\r"); break;
			case Quads:	xil_printf("quads\n\r"); break;
			case FHouse:	xil_printf("full house\n\r"); break;
			case Trips:	xil_printf("trips\n\r"); break;
			case TwoPair:	xil_printf("two pair\n\r"); break;
			case Pair:	xil_printf("pair\n\r"); break;
		}
		xil_printf("won $%d\n\r",sidepot/n);
		drawText("WIN\n", BLACK, stackRow[((j)+numplayers-(playerid-1))%numplayers]+4, stackCol[((j)+numplayers-(playerid-1))%numplayers]);
		drawBigChar(DOLLARSIGN, BLACK, stackRow[((j)+numplayers-(playerid-1))%numplayers]+6, stackCol[((j)+numplayers-(playerid-1))%numplayers]); 
		drawInt(sidepot/n, BLACK, stackRow[((j)+numplayers-(playerid-1))%numplayers]+6, stackCol[((j)+numplayers-(playerid-1))%numplayers]+2); 

		cash[j] += sidepot/n;
		delay_loop();
		sendStatus(2, j+1, sidepot/n);
		totalbet[j] = secondmaxbet;
	} else if (totalbet[j] > secondmaxbet) {
		totalbet[j] = secondmaxbet;
	}
	
  } 
  pot -= sidepot;
} 
//==================================================
//  getMax7()  - works on rank7[]
//  getMax7a() - works on rank7a[]
//    finds the maximum kicker value among
//    qualifying hands and advances the
//    qualifying player state counters
//--------------------------------------------------
int getMax7(int n) {
int max,j;
  max=0;
  for(j=0;j<num;j++) {
    if(rank7[j]>max && player[j]==n) max=rank7[j]; }
  for(j=0;j<num;j++) {
    if(rank7[j]==max && player[j]==n) player[j]=n+1; }
  return (max);
}
int getMax7a(int n) {
int max,j;
  max=0;
  for(j=0;j<num;j++) {
    if(rank7a[j]>max && player[j]==n) max=rank7a[j]; }
  for(j=0;j<num;j++) {
    if(rank7a[j]==max && player[j]==n) player[j]=n+1; }
  return (max);
}
//===================================================
//  getNHigh()
//    returns a count of the number of players
//    at the specified search state and advances
//    the qualifying player state counters
//---------------------------------------------------
int getNHigh(int n) {
int j,now;
  now=0;
  for(j=0;j<num;j++) if(player[j]==n) {
    now+=1; player[j]=n+1;}
  return now;
}
//===================================================
//  getHighHand()
//    finds the highest ranking hand type held
//    by any player, and then sets initial
//    search state for each qualifying player.
//--------------------------------------------------
int getHighHand() {
int j,high;
  for(j=0;j<numplayers;j++) player[j]=0;
  high=0;
  for(j=0;j<numplayers;j++)
	  if(hand7[j]>high && status[j] <= 3 && totalbet[j] == maxbet)
		  high=hand7[j];
  for(j=0;j<numplayers;j++)
	  if(hand7[j]==high && status[j] <= 3 && totalbet[j] == maxbet)
		  player[j]=1;
  return high;
}
//===================================================
//  resolveRank7()
//  resolveRank7a()
//    Look for highest kicker value, then counts
//    number of players with qualifying hands
//    holding it. If only 1 player does, the pot
//    is awarded. Otherwise function(s) return
//    flag signalling theres still competition.
//---------------------------------------------------
int resolveRank7(int high) {
int max,n;
  max=getMax7(2);  // now marked '3'
  n=getNHigh(3);   // now marked '4'
  if(n==1) {foundWins(4,high,1); return 0;}
  return 1;
}
int resolveRank7a(int high) {
int max,n;
  max=getMax7a(4);  // now marked '5'
  n=getNHigh(5);   // now marked '6'
  if(n==1) {foundWins(6,high,1); return 0;}
  return 1;
}
//===================================================
//  getWinner2()
//    Resolves winner by looking first at rank
//    of hand type, then at value of kicker
//---------------------------------------------------
void getWinner2(int np,int high) {
int n,max;
  if(resolveRank7(high)==0) return;
  if(resolveRank7a(high)==0) return;
  max=getMax7a(6);  // now marked '5'
  n=getNHigh(7);   // now marked '6'
  foundWins(8,high,n);
}
//===================================================
//  getWinner1()
//    Resolves winner by looking at the
//    rank of winning hand type.
//---------------------------------------------------
void getWinner1(int np,int high) {
int n;
  if(resolveRank7(high)==0) return;
  n=getNHigh(4);      // now '5'
  foundWins(5,high,n);
}
//====================================================
//  winners()
//    This function searches the specified
//    number of active hands and determines
//    the winner(s).
//----------------------------------------------------
void winners(int np) {
int n,p,high;
static int flag=0;
  if(flag==0) {flag=1;}
  if(np<2||np>numplayers) return;  // n players out of range
  //  find highest ranking hand type
  high=getHighHand();
  if(high<HighCard||high>SFlush) return;
  next1:
  n=getNHigh(1); // now '2'
  if(n==1) {foundWins(2,high,1); return;}
  //  drop down here only when theres more than
  //  one player holding the highest hand type
  switch(high) {
    case SFlush:
    case Flush:
    case Straight:
    case HighCard:
      getWinner1(numplayers,high);
      return;
    case Quads:
    case FHouse:
    case Trips:
    case TwoPair:
    case Pair:
      getWinner2(numplayers,high);
      return;
    } // switch



}
