//     XILINX IS PROVIDING THIS DESIGN, CODE, OR INFORMATION "AS IS"
//     SOLELY FOR USE IN DEVELOPING PROGRAMS AND SOLUTIONS FOR
//     XILINX DEVICES.  BY PROVIDING THIS DESIGN, CODE, OR INFORMATION
//     AS ONE POSSIBLE IMPLEMENTATION OF THIS FEATURE, APPLICATION
//     OR STANDARD, XILINX IS MAKING NO REPRESENTATION THAT THIS
//     IMPLEMENTATION IS FREE FROM ANY CLAIMS OF INFRINGEMENT,
//     AND YOU ARE RESPONSIBLE FOR OBTAINING ANY RIGHTS YOU MAY REQUIRE
//     FOR YOUR IMPLEMENTATION.  XILINX EXPRESSLY DISCLAIMS ANY
//     WARRANTY WHATSOEVER WITH RESPECT TO THE ADEQUACY OF THE
//     IMPLEMENTATION, INCLUDING BUT NOT LIMITED TO ANY WARRANTIES OR
//     REPRESENTATIONS THAT THIS IMPLEMENTATION IS FREE FROM CLAIMS OF
//     INFRINGEMENT, IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
//     FOR A PARTICULAR PURPOSE.
//
//     (c) Copyright 2002 Xilinx, Inc.
//     All rights reserved.
//


/*
-------------------------------------------------------------------------------
   Title      : SVGA Video Output Character Generator ROM
   Project    : MicroBlaze Demo Board
-------------------------------------------------------------------------------
   File       : CHAR_GEN_ROM.v
   Company    : Xilinx, Inc.
   Created    : 2001/07/17
   Last Update: 2001/07/17
   Copyright  : (c) Xilinx Inc, 2001
-------------------------------------------------------------------------------
   Uses       : 
-------------------------------------------------------------------------------
   Used by    : CHARACTER_MODE.v
-------------------------------------------------------------------------------
   Description: This module creates a 2k x 8 ROM that is used for video character generation.
			The ROM contents are also defined in the CHAR_GEN_ROM.ucf file.

			The charcter generator defines a 8 x 8 block of pixels used for ASCII characters,
			line graphics and Xilinx logo. The least significant 3 address bits define the line
			within the character block and the most significant 8 bits define the specific character.
			
			If the user wishes to extend the character set then the "INIT_20 - INIT_3F" values must be
			defined.

Code 	  00h  	defines a solid block
Codes 01h-04h	defines the Xilinx logo
Codes 05h-1Fh	defines line graphics		
Codes 20h-7Fh 	defines the ASCII characters
Codes 80h-FFh  	user defined characters

-------------------------------------------------------------------------------

-------------------------------------------------------------------------------
*/


module CHAR_GEN_ROM (pixel_clock,address,data);
input			pixel_clock;
input [10:0]	address;
output [7:0] 	data;
wire           	pixel_clock;
wire  [10:0]   	address;
wire   [7:0]   	data;

// instantiate the RAM used as a ROM

RAMB16_S9 CHARACTER_GEN_ROM (
.DO(data),
.DOP(),
.ADDR(address[10:0]),
.DI(8'h00),
.DIP(1'b0),
.EN(1'b1),
.CLK(pixel_clock),
.WE(1'b0),				// no write enable
.SSR(1'b0)
);


defparam CHARACTER_GEN_ROM .INIT_00 = 256'h000080C0E0F0F8FC000103070F1F3F7FFEFCF8F0E0C08000FF7F3F1F0F070301; //diamond
defparam CHARACTER_GEN_ROM .INIT_01 = 256'h00F0E0C08C9EFFFF000F07033179FFFFFFFECCC0E0E0C080FF7F330307070301; //club
defparam CHARACTER_GEN_ROM .INIT_02 = 256'h000080C0E0F0F8FC00000103070F1F3FFEFFFFFFFFFF7E3C7FFFFFFFFFFF7E3C; //heart
defparam CHARACTER_GEN_ROM .INIT_03 = 256'h00C080387CFEFEFE000703397DFFFFFFFEFCF8F0E0C08000FF7F3F1F0F070301; //spade
defparam CHARACTER_GEN_ROM .INIT_04 = 256'h0000C0E03030303000000F1F30383C3E30B0F0F07030E0C03733313030301F0F; //0
defparam CHARACTER_GEN_ROM .INIT_05 = 256'h0000C0C00000000000000F0F030303030000000000000000030303030F0F0703; //1
defparam CHARACTER_GEN_ROM .INIT_06 = 256'h0000F0F00000008000003F3F1C0E0703C0E070303070E0C00100000030381F0F; //2
defparam CHARACTER_GEN_ROM .INIT_07 = 256'h0000C0E07030307000000F1F38300000E0C08080C0E0F0F00001030301003F3F; //3
defparam CHARACTER_GEN_ROM .INIT_08 = 256'h0000C0C0C0C0F0F00000000000003F3FC0C0C0C0C0C0C0C030381C0E07030100; //4
defparam CHARACTER_GEN_ROM .INIT_09 = 256'h0000C0E07030303000000F1F383000003070E0C00000F0F000003F3F30303F3F; //5
defparam CHARACTER_GEN_ROM .INIT_0A = 256'h0000C0E07030307000000F1F38303030E0C000000000C0C03F3F30381C0E0703; //6
defparam CHARACTER_GEN_ROM .INIT_0B = 256'h000000000000000000000C0C0C0C0C0E0080C0E07030F0F00703010000003F3F; //7
defparam CHARACTER_GEN_ROM .INIT_0C = 256'h0000C0E07030307000000F1F38303038E0E070303070E0C01F1F383030381F0F; //8
defparam CHARACTER_GEN_ROM .INIT_0D = 256'h00000080C0E0707000000F0F01000000F0F070303070E0C00F1F383030381F0F; //9
defparam CHARACTER_GEN_ROM .INIT_0E = 256'h0000C0E0F030303000003031333333333030303030F0E0C03333333333333130; //10
defparam CHARACTER_GEN_ROM .INIT_0F = 256'h000030303030F0F00000303030303F3F303030303070E0C03030303030381F0F; //A

defparam CHARACTER_GEN_ROM .INIT_10 = 256'h0000C0E07030307000003F3F30303030E0E070303070E0C03F3F303030303F3F; //B
defparam CHARACTER_GEN_ROM .INIT_11 = 256'h0000C0E07030000000000F1F38303030000000003070E0C03030303030381F0F; //C
defparam CHARACTER_GEN_ROM .INIT_12 = 256'h00000080C0E0703000003F3F3130303030303070E0C080003030303030313F3F; //D
defparam CHARACTER_GEN_ROM .INIT_13 = 256'h0000F0F00000000000003F3F30303030C0C000000000F0F03F3F303030303F3F; //E
defparam CHARACTER_GEN_ROM .INIT_14 = 256'h00000000000000000000303030303030C0C000000000F0F03F3F303030303F3F; //F
defparam CHARACTER_GEN_ROM .INIT_15 = 256'h0000C0E07030303000000F1F38303030F0F000003070E0C03333303030381F0F; //G
defparam CHARACTER_GEN_ROM .INIT_16 = 256'h00003030303030300000303030303030F0F03030303030303F3F303030303030; //H
defparam CHARACTER_GEN_ROM .INIT_17 = 256'h0000C0C00000000000000F0F03030303000000000000C0C00303030303030F0F; //I
defparam CHARACTER_GEN_ROM .INIT_18 = 256'h00000080C0C0C0C00000070F0D0C0000C0C0C0C0C0C0F0F00000000000000303; //J
defparam CHARACTER_GEN_ROM .INIT_19 = 256'h00003070E0C08000000030303031333700000080C0E070303E3E373331303030; //K
defparam CHARACTER_GEN_ROM .INIT_1A = 256'h0000F0F00000000000003F3F3030303000000000000000003030303030303030; //L
defparam CHARACTER_GEN_ROM .INIT_1B = 256'h00003030303030300000303030303030303030B0F0F07030303033373F3C3830; //M
defparam CHARACTER_GEN_ROM .INIT_1C = 256'h000030303070F0F00000303030303031B03030303030303033373E3C38303030; //N
defparam CHARACTER_GEN_ROM .INIT_1D = 256'h0000C0E07030303000000F1F38303030303030303070E0C03030303030381F0F; //O
defparam CHARACTER_GEN_ROM .INIT_1E = 256'h00000000000000000000303030303030C0E070303070E0C03F3F303030303F3F; //P
defparam CHARACTER_GEN_ROM .INIT_1F = 256'h000030F0E0E0B03000000F1F38313333303030303070E0C03030303030381F0F; //Q

defparam CHARACTER_GEN_ROM .INIT_20 = 256'h00003070E0C080000000303030313337C0E070303070E0C03F3F303030303F3F; //R
defparam CHARACTER_GEN_ROM .INIT_21 = 256'h0000C0E07030307000003F3F00000000E0C000000000F0F00F1F383030381F0F; //S
defparam CHARACTER_GEN_ROM .INIT_22 = 256'h00000000000000000000030303030303000000000000F0F00303030303033F3F; //T
defparam CHARACTER_GEN_ROM .INIT_23 = 256'h0000C0E07030303000000F1F3830303030303030303030303030303030303030; //U
defparam CHARACTER_GEN_ROM .INIT_24 = 256'h00000080C0E07030000003070F1C383030303030303030303030303030303030; //V
defparam CHARACTER_GEN_ROM .INIT_25 = 256'h0000C0E0F030303000000C1F3F33333330303030303030303333303030303030; //W
defparam CHARACTER_GEN_ROM .INIT_26 = 256'h000030303070E0C00000303030381C0F8080C0E07030303007070F1C38303030; //X
defparam CHARACTER_GEN_ROM .INIT_27 = 256'h00000000000000800000030303030307C0E07030303030300F1C383030303030; //Y
defparam CHARACTER_GEN_ROM .INIT_28 = 256'h0000F0F00000000000003F3F30381C0E0080C0E07030F0F00703010000003F3F; //Z
defparam CHARACTER_GEN_ROM .INIT_29 = 256'hFFFF000000000000000000000000FFFFC0C0C0C0C0C0C0C00303030303030303; //BOTTOMLINE,TOPLINE,LEFTLINE,RIGHTLINE
defparam CHARACTER_GEN_ROM .INIT_2A = 256'hFCF8F8F0E0800000FFFFFFFFFFFFFEF0FFFFFFFFFFFF7F0F3F1F1F0F07010000; //CIRCLE(TOP)
defparam CHARACTER_GEN_ROM .INIT_2B = 256'hFCFEFEFEFFFFFFFF3F7F7F7FFFFFFFFFFFFFFFFFFEFEFEFCFFFFFFFF7F7F7F3F; //CIRCLE(MID)
defparam CHARACTER_GEN_ROM .INIT_2C = 256'h000080E0F0F8F8FCF0FEFFFFFFFFFFFF0F7FFFFFFFFFFFFF000001070F1F1F3F; //CIRCLE(BOT)
defparam CHARACTER_GEN_ROM .INIT_2D = 256'hF0FEFFFFFFFF0F010F7FFFFFFFFFF0807C1E8EEEF2FBF9FD3E7871774FDF9FBF; //STACK
defparam CHARACTER_GEN_ROM .INIT_2E = 256'h00000000C0E07070000003033F3F0303E0C00000F0F000000F1F3B3B1F0F0303; //DOLLARSIGN
defparam CHARACTER_GEN_ROM .INIT_2F = 256'h0000000000000000000000000000000000000000000000000000000000000000; //

defparam CHARACTER_GEN_ROM .INIT_30 = 256'h0000000000000000000000000000000000000000000000000000000000000000; //
defparam CHARACTER_GEN_ROM .INIT_31 = 256'h0000000000000000000000000000000000000000000000000000000000000000; //
defparam CHARACTER_GEN_ROM .INIT_32 = 256'h0000000000000000000000000000000000000000000000000000000000000000; //
defparam CHARACTER_GEN_ROM .INIT_33 = 256'h0000000000000000000000000000000000000000000000000000000000000000; //
defparam CHARACTER_GEN_ROM .INIT_34 = 256'h0000000000000000000000000000000000000000000000000000000000000000; //
defparam CHARACTER_GEN_ROM .INIT_35 = 256'h0000000000000000000000000000000000000000000000000000000000000000; //
defparam CHARACTER_GEN_ROM .INIT_36 = 256'h0000000000000000000000000000000000000000000000000000000000000000; //
defparam CHARACTER_GEN_ROM .INIT_37 = 256'h0000000000000000000000000000000000000000000000000000000000000000; //
defparam CHARACTER_GEN_ROM .INIT_38 = 256'h0000000000000000000000000000000000000000000000000000000000000000; //
defparam CHARACTER_GEN_ROM .INIT_39 = 256'h0000000000000000000000000000000000000000000000000000000000000000; //
defparam CHARACTER_GEN_ROM .INIT_3A = 256'h0000000000000000000000000000000000000000000000000000000000000000; //
defparam CHARACTER_GEN_ROM .INIT_3B = 256'h0000000000000000000000000000000000000000000000000000000000000000; //
defparam CHARACTER_GEN_ROM .INIT_3C = 256'h0000000000000000000000000000000000000000000000000000000000000000; //
defparam CHARACTER_GEN_ROM .INIT_3D = 256'h0000000000000000000000000000000000000000000000000000000000000000; //
defparam CHARACTER_GEN_ROM .INIT_3E = 256'h0000000000000000000000000000000000000000000000000000000000000000; //
defparam CHARACTER_GEN_ROM .INIT_3F = 256'h0000000000000000FFFFFFFFFFFFFFFF00000000000000000000000000000000; //



// synthesis translate_on


endmodule//CHAR_GEN_ROM




