//     XILINX IS PROVIDING THIS DESIGN, CODE, OR INFORMATION "AS IS"
//     SOLELY FOR USE IN DEVELOPING PROGRAMS AND SOLUTIONS FOR
//     XILINX DEVICES.  BY PROVIDING THIS DESIGN, CODE, OR INFORMATION
//     AS ONE POSSIBLE IMPLEMENTATION OF THIS FEATURE, APPLICATION
//     OR STANDARD, XILINX IS MAKING NO REPRESENTATION THAT THIS
//     IMPLEMENTATION IS FREE FROM ANY CLAIMS OF INFRINGEMENT,
//     AND YOU ARE RESPONSIBLE FOR OBTAINING ANY RIGHTS YOU MAY REQUIRE
//     FOR YOUR IMPLEMENTATION.  XILINX EXPRESSLY DISCLAIMS ANY
//     WARRANTY WHATSOEVER WITH RESPECT TO THE ADEQUACY OF THE
//     IMPLEMENTATION, INCLUDING BUT NOT LIMITED TO ANY WARRANTIES OR
//     REPRESENTATIONS THAT THIS IMPLEMENTATION IS FREE FROM CLAIMS OF
//     INFRINGEMENT, IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
//     FOR A PARTICULAR PURPOSE.
//
//     (c) Copyright 2002 Xilinx, Inc.
//     All rights reserved.
//

 /*

-------------------------------------------------------------------------------
   Title      : SVGA Controller
   Project    : MicroBlaze Demo Board
-------------------------------------------------------------------------------
   File       : COLOR_CHAR_MODE_SVGA_CTRL.v
   Company    : Xilinx, Inc.
   Created    : 2001/06/20
   Last Update: 2001/06/20
   Copyright  : (c) Xilinx Inc, 2001
-------------------------------------------------------------------------------
   Uses       : SVGA_TIMING_GENERATION.v DRIVE_DAC_DATA.v CHARACTER_MODE.v CLUT.v
			COLOR_RAM.v
-------------------------------------------------------------------------------
   Used by    : 
-------------------------------------------------------------------------------
   Description: This is the top level module for the color character mode SVGA display.
   	This design supports screen resolutions up to 800 x 600 (75 rows of 100 characters).
	This module uses 6 block RAMS to store the ASCII characters and the color definitions
	and a block RAM as a character generator ROM. No external RAMS are required. 
	3 additional block RAMS are required if the resolution is increased to 1024 x 768
	the maximum supported by the SVGA_TIMING_GENERATION module.

	The user has unrestricted access to the video memory because of the two port
	behavior of the BRAMS.


	Conventions:
		All external port signals are UPPER CASE.
		Active HIGH PORT signals have a P suffex
		Active LOW PORT signals have a N suffex.
		All internal signals are LOWER CASE and are active HIGH.

-------------------------------------------------------------------------------
-------------------------------------------------------------------------------
*/
module char_mode_svga_ctrl (
VGA_OUT_PIXEL_CLOCK_P,
VGA_COMP_SYNCH_N,
VGA_OUT_BLANK_N,
VGA_HSYNCH_N,
VGA_VSYNCH_N,
VGA_OUT_RED_P,
VGA_OUT_GREEN_P,
VGA_OUT_BLUE_P,

char_write_addr,
char_write_data,
char_write_enable,
char_write_clock,

color_write_addr,
color_write_data,
color_write_enable,
//color_write_clock,

pixel_clock,
reset
);

output 			VGA_OUT_PIXEL_CLOCK_P;	// pixel clock for the video DAC
output			VGA_COMP_SYNCH_N;		// composite sync for the video DAC
output 			VGA_OUT_BLANK_N;		// composite blanking for the video DAC
output 			VGA_HSYNCH_N;			// horizontal sync for the VGA output connector
output			VGA_VSYNCH_N;			// vertical sync for the VGA output connector
output [7:0] 	VGA_OUT_RED_P;			// RED DAC data
output [7:0] 	VGA_OUT_GREEN_P;		// GREEN DAC data
output [7:0] 	VGA_OUT_BLUE_P;			// BLUE DAC data

input [0:31]		char_write_addr;		// address of character to be written into memory
input [0:31]		char_write_data;		// ASCII data of character to be written
input 			char_write_enable;		// write enable
input			char_write_clock		/* synthesis syn_noclockbuf = 1 */; // write clock

input [0:31]		color_write_addr;		// address of the color data to be written into memory
input [0:31]		color_write_data;		// character color data
input			color_write_enable;		// write enable
//input			color_write_clock		/* synthesis syn_noclockbuf = 1 */; // write clock

input	 		pixel_clock				/* synthesis syn_noclockbuf = 1 */; // pixel clock input 
input			reset;					// reset

wire			VGA_OUT_PIXEL_CLOCK_P;
reg 			VGA_COMP_SYNCH_N;
reg				VGA_OUT_BLANK_N;
reg				VGA_HSYNCH_N;
reg				VGA_VSYNCH_N;
reg	[7:0]		VGA_OUT_RED_P; 
reg	[7:0]		VGA_OUT_GREEN_P; 
reg	[7:0]		VGA_OUT_BLUE_P; 

wire [7:0]		bm_red_data;
wire [7:0]		bm_green_data; 
wire [7:0]		bm_blue_data; 

wire 			bm_display_active;
wire 			char_display_active;
wire [7:0]		dac_red_data;
wire [7:0]		dac_green_data;
wire [7:0]		dac_blue_data;


wire 			h_synch_delay;
wire 			v_synch_delay;
wire 			comp_synch;
wire 			blank;
wire [2:0]		char_line_count;
wire [13:0]		char_mode_address;
wire [7:0]		char_mode_data;
wire [13:0]		char_address;
wire [2:0]		char_pixel;
wire [19:0]		vga_ram_read_address;

wire 			pixel_clock;
wire 			reset;

wire [7:0] 	red_data;
wire [7:0] 	green_data;
wire [7:0] 	blue_data;
wire		pixel_data;
wire [3:0] 	aligned_color_data;
wire [3:0] 	color_ram_data;

wire		color_read_clock;
wire [3:0] 	color_read_data;
wire [12:0] color_read_addr;
wire		color_read_enable;

//wire		color_write_clock;
//wire [3:0]  color_write_data;
//wire [12:0] color_write_addr;
//wire		color_write_enable;



// make the internal connections
assign bm_red_data 		= red_data;
assign bm_green_data 	= green_data;
assign bm_blue_data 	= blue_data;

assign bm_display_active = 1'b1;
assign char_display_active = 1'b0;
assign char_address [13:0] = char_mode_address[13:0];	// one spare bit for 1024 x 768 expansion

assign color_ram_data[3:0] = color_read_data[3:0];

assign color_read_clock = pixel_clock;
assign color_read_enable = 1'b1;
assign color_ram_data[3:0] = color_read_data[3:0];
assign color_read_addr[12:0] = char_mode_address[12:0];

assign pixel_data = char_mode_data[0];


// make the external connections
// shut down the video output during  reset
always @ (posedge pixel_clock or posedge reset) begin
	if (reset) begin
		VGA_HSYNCH_N	 	<= 1'b1;
		VGA_VSYNCH_N 	 	<= 1'b1;
		VGA_COMP_SYNCH_N 	<= 1'b1;
		VGA_OUT_BLANK_N 	<= 1'b0;
		VGA_OUT_RED_P		<= 8'h00;
		VGA_OUT_GREEN_P		<= 8'h00;
		VGA_OUT_BLUE_P		<= 8'h00;
		end
	else begin
		VGA_HSYNCH_N	 	<= !h_synch_delay;
		VGA_VSYNCH_N 	 	<= !v_synch_delay;
//		VGA_COMP_SYNCH_N 	<= !comp_synch;
		VGA_COMP_SYNCH_N 	<= 1'b1;
		VGA_OUT_BLANK_N 	<= !blank;
		VGA_OUT_RED_P		<= dac_red_data;
		VGA_OUT_GREEN_P		<= dac_green_data;
		VGA_OUT_BLUE_P		<= dac_blue_data;
		end
	end

assign  VGA_OUT_PIXEL_CLOCK_P	= pixel_clock;

// instantiate the SVGA timing generator
SVGA_TIMING_GENERATION SVGA_TIMING_GENERATION(
pixel_clock,
reset,
h_synch_delay,
v_synch_delay,
comp_synch,
blank,
char_line_count,
char_mode_address,
char_pixel
);

// instantiate the character RAM and character generator ROM
CHARACTER_MODE CHARACTER_MODE(
char_write_addr[19:31],
char_write_data[24:31],
char_write_enable,
char_write_clock,
char_address,
char_line_count,
char_pixel,
pixel_clock,
char_mode_data,
reset
);


// instantiate the color RAM
COLOR_RAM COLOR_RAM (
color_read_clock,
color_read_data,
color_read_addr,
color_read_enable,
color_write_data[28:31],
color_write_addr[19:31],
char_write_clock,
color_write_enable);




// instantiate the color pipeline
COLOR_PIPE COLOR_PIPE (
color_ram_data, 
pixel_clock, 
reset, 
aligned_color_data);

// instantiate the color look up table
CLUT CLUT (
aligned_color_data, 
pixel_data, 
pixel_clock, 
reset, 
red_data, 
green_data, 
blue_data);

// instantiate the DAC driver
DRIVE_DAC_DATA DRIVE_DAC_DATA(
bm_red_data, 
bm_green_data, 
bm_blue_data, 
char_mode_data,
bm_display_active,
char_display_active,
dac_red_data,
dac_green_data,
dac_blue_data
);

endmodule //COLOR_CHAR_MODE_SVGA_CTRL